import { ContextTracker, ExternalTokenizer, LRParser } from '@lezer/lr';
import { LRLanguage, indentNodeProp, continuedIndent, delimitedIndent, foldNodeProp, foldInside, LanguageSupport } from '@codemirror/language';
import { styleTags, tags } from '@lezer/highlight';
import { completeFromList } from '@codemirror/autocomplete';

// Note that 'eval' and 'do' are not in this list as they can accept a block.
const namedUnaryOperators = [
    'abs',
    'alarm',
    'await',
    'caller',
    'chdir',
    'chr',
    'chroot',
    'close',
    'closedir',
    'cos',
    'defined',
    'delete',
    'eof',
    'evalbytes',
    'exists',
    'exit',
    'exp',
    'fileno',
    'getc',
    'gethostbyname',
    'getnetbyname',
    'getpgrp',
    'getprotobyname',
    'glob',
    'gmtime',
    'hex',
    'int',
    'lc',
    'lcfirst',
    'length',
    'localtime',
    'lock',
    'log',
    'lstat',
    'oct',
    'ord',
    'pos',
    'quotemeta',
    'rand',
    'readdir',
    'readline',
    'readlink',
    'readpipe',
    'reset',
    'rewinddir',
    'ref',
    'rmdir',
    'scalar',
    'select',
    'sin',
    'sleep',
    'sqrt',
    'srand',
    'stat',
    'tell',
    'telldir',
    'tied',
    'uc',
    'ucfirst',
    'umask',
    'undef',
    'untie'
];
// The list operators that can operate on a block (grep, map, join, sort, and unpack) are handled separately.
const listOperators = [
    'atan2',
    'chomp',
    'chop',
    'chmod',
    'chown',
    'crypt',
    'die',
    'fcntl',
    'flock',
    'getpriority',
    'index',
    'ioctl',
    'kill',
    'link',
    'mkdir',
    'open',
    'opendir',
    'pack',
    'pipe',
    'read',
    'rename',
    'reverse',
    'rindex',
    'seek',
    'seekdir',
    'setpgrp',
    'setpriority',
    'split',
    'sprintf',
    'substr',
    'symlink',
    'syscall',
    'sysopen',
    'sysread',
    'sysseek',
    'syswrite',
    'tie',
    'truncate',
    'unlink',
    'utime',
    'vec',
    'waitpid',
    'warn'
];

// This file was generated by lezer-generator. You probably shouldn't edit it.
const automaticSemicolon = 309, statementEnd = 310, UnrestrictedIdentifier = 1, SpecialScalarVariable = 2, NamedUnaryOperator = 3, ListOperator = 4, FileTestOp = 5, IOOperatorStart = 6, Glob = 7, ReadonlySTDIN = 8, IOOperatorEnd = 9, HeredocStartIdentifier = 10, uninterpolatedHeredocStart = 311, interpolatedHeredocStart = 312, HeredocEndIdentifier = 11, InterpolatedStringContent = 12, EscapeSequence = 13, afterInterpolation = 313, packageNamePart = 314, afterPackageName = 315, QuoteLikeStartDelimiter = 14, QuoteLikeSeparatorDelimiter = 15, QuoteLikeEndDelimiter = 16, StringContent = 17, QWElement = 18, patternMatchStart = 316, RegexOptions = 19, regexEnd = 317, PodDirective = 20, PodContent = 21, PodCut = 22, endDataBlock = 318, q = 42, qq = 45, qw = 71, qx = 82, m = 84, qr = 88, s = 90, tr = 92, y = 93, Prototype = 111, PackageName = 121;

const isUpperCaseASCIILetter = (ch) => ch >= 65 && ch <= 90;
const isLowerCaseASCIILetter = (ch) => ch >= 97 && ch <= 122;
const isASCIILetter = (ch) => isLowerCaseASCIILetter(ch) || isUpperCaseASCIILetter(ch);
const isDigit = (ch) => ch >= 48 && ch <= 55;
const isIdentifierChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch) || isDigit(ch);
const isVariableStartChar = (ch) => ch == 95 /* _ */ || isASCIILetter(ch);
const isRegexOptionChar = (ch, regexType) => {
    if (regexType === tr || regexType === y) {
        if (ch == 99 /* c */ || ch == 100 /* d */ || ch == 115 /* s */ || ch == 114 /* r */)
            return true;
        return false;
    }
    if (ch == 109 /* m */ ||
        ch == 115 /* s */ ||
        ch == 105 /* i */ ||
        ch == 120 /* x */ ||
        ch == 112 /* p */ ||
        ch == 111 /* o */ ||
        ch == 100 /* d */ ||
        ch == 117 /* u */ ||
        ch == 97 /* a */ ||
        ch == 108 /* l */ ||
        ch == 110 /* n */)
        return true;
    if ((regexType === m || regexType === s) && (ch == 103 /* g */ || ch == 99) /* c */)
        return true;
    if (regexType == s && (ch == 101 /* e */ || ch == 114) /* r */)
        return true;
    return false;
};
// !"$%&'()*+,-./0123456789:;<=>?@[\]`~
// For arrays this is only used for interpolation and in that case only @$, @+, @-, and @1 .. @9 are allowed.
const isSpecialVariableChar = (ch, arrayType = false) => arrayType
    ? ch == 36 || ch == 43 || ch == 45 || (ch >= 49 && ch <= 57)
    : (ch >= 33 && ch != 35 && ch <= 64) || ch == 91 || ch == 92 || ch == 93 || ch == 96 || ch == 126;
/* 0-9, a-f, A-F */
const isHex = (ch) => (ch >= 48 && ch <= 55) || (ch >= 97 && ch <= 102) || (ch >= 65 && ch <= 70);
// ' ', \t, \n, \r
const isWhitespace = (ch) => ch == 32 || ch == 9 || ch == 10 || ch == 13;
const gobbleWhitespace = (input) => {
    while (isWhitespace(input.next))
        input.advance();
};
// rwxoRWXOezsfdlpSbctugkTBMAC
const isFileTestOperatorChar = (ch) => ch == 114 ||
    ch == 119 ||
    ch == 120 ||
    ch == 111 ||
    ch == 82 ||
    ch == 87 ||
    ch == 88 ||
    ch == 79 ||
    ch == 101 ||
    ch == 122 ||
    ch == 115 ||
    ch == 102 ||
    ch == 100 ||
    ch == 108 ||
    ch == 112 ||
    ch == 83 ||
    ch == 98 ||
    ch == 99 ||
    ch == 116 ||
    ch == 117 ||
    ch == 103 ||
    ch == 107 ||
    ch == 84 ||
    ch == 66 ||
    ch == 77 ||
    ch == 65 ||
    ch == 67;
const heredocQueue = [];
// Base class that all tracker contexts extend.
class Context {
    type;
    parent;
    stackPos;
    // Used by quote and quoteLike operators.
    startDelimiter;
    endDelimiter;
    // Used by quoteLike operators.
    quoteLikeType;
    nestLevel = 0;
    // Used by heredocs.
    tag;
    indented = false;
    inBody = false;
    newlinePos;
    // Used by any interpolating context.
    interpolating = false;
    constructor(type, parent = null, stackPos = -1, options = {}) {
        this.type = type;
        this.parent = parent;
        this.stackPos = stackPos;
        this.quoteLikeType = options.quoteLikeType;
        this.interpolating = options.interpolating ?? true;
        this.indented = options.indented ?? false;
        if (options.tag)
            this.tag = options.tag;
        if (typeof options.startDelimiter === 'number')
            this.setStartAndEndDelimiters(options.startDelimiter);
        if (typeof options.newlinePos === 'number')
            this.newlinePos = options.newlinePos;
    }
    setStartAndEndDelimiters(start) {
        this.startDelimiter = start;
        if (start == 40 /* ( */) {
            this.endDelimiter = 41 /* ) */;
        }
        else if (start == 60 /* < */) {
            this.endDelimiter = 62 /* > */;
        }
        else if (start == 91 /* [ */) {
            this.endDelimiter = 93 /* ] */;
        }
        else if (start == 123 /* { */) {
            this.endDelimiter = 125 /* } */;
        }
        else
            this.endDelimiter = start;
    }
    atEnd(input) {
        if (this.type === 'heredoc') {
            if (!this.tag || input.peek(-1) !== 10)
                return false;
            let pos = 0;
            if (this.indented) {
                let nextChar = input.peek(pos);
                while (isWhitespace(nextChar))
                    nextChar = input.peek(++pos);
            }
            for (const tagCh of this.tag) {
                if (input.peek(pos++) !== tagCh)
                    return false;
            }
            if (input.peek(pos) < 0 || input.peek(pos) == 10)
                return pos;
            return false;
        }
        else {
            return input.next === this.endDelimiter ? 1 : false;
        }
    }
}
const contextTracker = new ContextTracker({
    start: new Context('root'),
    shift(context, term, stack, input) {
        if (term === q || term === qq || term === qx || term === qw) {
            return new Context('quoteLike', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === m || term === qr || term === s || term === tr || term === y) {
            return new Context('quoteLike&regex', context, stack.pos, { quoteLikeType: term });
        }
        else if (term === IOOperatorStart) {
            return new Context('iooperator', context);
        }
        else if (term === HeredocStartIdentifier) {
            let pos = 0;
            const indented = input.next == 126; /* ~ */
            if (indented)
                ++pos;
            let haveWhitespace = false;
            while (isWhitespace(input.peek(pos))) {
                haveWhitespace = true;
                ++pos;
            }
            const quote = input.peek(pos) == 39 /* ' */ || input.peek(pos) == 34 /* " */ || input.peek(pos) == 96 /* ` */
                ? input.peek(pos)
                : undefined;
            if (!quote && haveWhitespace)
                return context;
            if (quote)
                ++pos;
            const backslashedTag = !quote && input.peek(pos) == 92; /* \\ */
            if (backslashedTag && (haveWhitespace || isWhitespace(input.peek(++pos))))
                return context;
            if (!isIdentifierChar(input.peek(pos)))
                return context;
            const tag = [input.peek(pos++)];
            for (;;) {
                const next = input.peek(pos++);
                if (!isIdentifierChar(next))
                    break;
                tag.push(next);
            }
            if (heredocQueue[0]?.stackPos !== stack.pos) {
                while (input.peek(pos) != 10 /* \n */ && input.peek(pos) >= 0)
                    ++pos;
                heredocQueue.unshift(new Context('heredoc', context, stack.pos, {
                    tag,
                    interpolating: (!quote || quote == 34 || quote == 96) && !backslashedTag,
                    indented,
                    newlinePos: input.pos + pos
                }));
            }
            return context;
        }
        else if (term === patternMatchStart) {
            if (input.next == 47 /* / */)
                return new Context('regex', context, stack.pos, { startDelimiter: 47, quoteLikeType: m });
        }
        else if ((context.type !== 'quote' || input.next != context.endDelimiter) &&
            term !== InterpolatedStringContent) {
            if (input.next == 34 /* " */ || input.next == 96 /* ` */) {
                return new Context('quote', context, stack.pos, { startDelimiter: input.next });
            }
        }
        if (context.type.startsWith('quoteLike') && term === QuoteLikeStartDelimiter) {
            let pos = 1;
            let startDelimiter = input.next;
            while (isWhitespace(startDelimiter))
                startDelimiter = input.peek(pos++);
            if (startDelimiter >= 0) {
                context.setStartAndEndDelimiters(startDelimiter);
                // Note that q and qw are not interpolated, but don't need to set this because they can't accept
                // interpolated content.
                if (context.quoteLikeType === tr ||
                    context.quoteLikeType === y ||
                    ((context.quoteLikeType === m ||
                        context.quoteLikeType === qr ||
                        context.quoteLikeType === qx ||
                        context.quoteLikeType === s) &&
                        startDelimiter == 39) /* ' */)
                    context.interpolating = false;
                return context;
            }
        }
        if ((term === interpolatedHeredocStart || term === uninterpolatedHeredocStart) &&
            heredocQueue.slice(-1)[0]?.newlinePos !== context.newlinePos) {
            const heredocContext = heredocQueue.pop();
            if (heredocContext) {
                heredocContext.parent = context;
                heredocContext.inBody = true;
                return heredocContext;
            }
        }
        if (context.parent &&
            ((context.type === 'quote' && input.next === context.endDelimiter) ||
                (context.type === 'quoteLike' && term === QuoteLikeEndDelimiter) ||
                (context.type === 'regex' && term === regexEnd) ||
                (context.type === 'quoteLike&regex' && term === regexEnd) ||
                (context.type === 'heredoc' && term === HeredocEndIdentifier) ||
                (context.type === 'iooperator' && term === IOOperatorEnd))) {
            return context.parent;
        }
        return context;
    },
    strict: false
});
const semicolon = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(statementEnd) &&
        !heredocQueue.length &&
        (input.peek(-1) == 59 /* ; */ ||
            (input.peek(-1) != 59 /* ; */ && (input.next < 0 || input.next == 10))) /* \n */) {
        input.acceptToken(statementEnd, 0);
    }
    else if (stack.canShift(automaticSemicolon) &&
        input.next != 59 /* ; */ &&
        (input.next < 0 || input.next == 125) /* } */)
        input.acceptToken(automaticSemicolon);
});
const unrestrictedIdentifier = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(UnrestrictedIdentifier)) {
        gobbleWhitespace(input);
        if (input.next < 0 || isASCIILetter(input.next) || input.next == 95 /* _ */)
            return;
        while (input.next >= 0 && isIdentifierChar(input.next))
            input.advance();
        input.acceptToken(UnrestrictedIdentifier);
    }
});
// Note that is only to pick up special variables that won't be considered as a ScalarVariable already.
const specialScalarVariable = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(SpecialScalarVariable) && input.next == 36 /* $ */) {
        if (stack.canShift(Prototype))
            return;
        const first = input.peek(1);
        const second = input.peek(2);
        if (first == 123 /* { */ && isSpecialVariableChar(second) && input.peek(3) == 125 /* } */) {
            input.acceptToken(SpecialScalarVariable, 4);
            return;
        }
        if (first == 123 /* { */ && second == 94 /* ^ */) {
            let pos = 3, ch;
            while ((isUpperCaseASCIILetter((ch = input.peek(pos))) || ch == 95) /* _ */ && ch != 125 /* } */)
                ++pos;
            if (ch == 125) {
                input.acceptToken(SpecialScalarVariable, pos + 1);
                return;
            }
        }
        if (first == 94 /* ^ */ && (isUpperCaseASCIILetter(second) || second == 95) /* _ */) {
            input.acceptToken(SpecialScalarVariable, 3);
            return;
        }
        if (!isSpecialVariableChar(first))
            return;
        if (first == 36 /* $ */ && isIdentifierChar(second))
            return;
        input.acceptToken(SpecialScalarVariable, 2);
        return;
    }
});
// Finds the longest lower case word coming up in the stream.  Returns an array
// containing the word and the ascii character code of the next character after it.
const peekLCWord = (input) => {
    let pos = 0;
    let word = '', nextChar;
    while (isLowerCaseASCIILetter((nextChar = input.peek(pos)))) {
        ++pos;
        word += String.fromCharCode(nextChar);
    }
    return [word, nextChar];
};
const builtinOperator = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(NamedUnaryOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (namedUnaryOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(NamedUnaryOperator, word.length);
    }
    if (stack.canShift(ListOperator)) {
        const [word, nextChar] = peekLCWord(input);
        if (listOperators.includes(word) && !isIdentifierChar(nextChar))
            input.acceptToken(ListOperator, word.length);
    }
});
const fileIO = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(FileTestOp) && !stack.canShift(PackageName)) {
        gobbleWhitespace(input);
        if (input.next == 45 /* - */ && isFileTestOperatorChar(input.peek(1)) && !isASCIILetter(input.peek(2)))
            input.acceptToken(FileTestOp, 2);
    }
    // Start an IO operator if the following input contains a '<' character that is not followed by another
    // one or the following input specifically contains <<>>.
    if (stack.canShift(IOOperatorStart) &&
        input.next == 60 &&
        (input.peek(1) != 60 || (input.peek(2) == 62 && input.peek(3) == 62))) {
        input.acceptToken(IOOperatorStart, 1);
        return;
    }
    if (!(stack.context instanceof Context) || stack.context.type !== 'iooperator')
        return;
    // End the IO operator when the '>' character is encountered.
    if (stack.canShift(IOOperatorEnd) && input.next == 62) {
        input.acceptToken(IOOperatorEnd, 1);
        return;
    }
    // In this case the initial '<' started the IO operator, and what follows is '<>>'
    // to finish the read only standard input declaration.
    if (input.peek(0) == 60 && input.peek(1) == 62 && input.peek(2) == 62) {
        input.acceptToken(ReadonlySTDIN, 2);
        return;
    }
    let pos = 0, ch;
    const isPossibleVariable = input.next == 36; /* $ */
    if (isPossibleVariable)
        ++pos;
    let haveWhitespace = false, haveNonASCII = false;
    while ((ch = input.peek(pos)) >= 0 && ch != 62 /* > */) {
        if (isWhitespace(ch))
            haveWhitespace = true;
        if (!isASCIILetter(ch))
            haveNonASCII = true;
        ++pos;
    }
    if ((isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        (!isPossibleVariable && !haveWhitespace && !haveNonASCII) ||
        ch < 0)
        return;
    input.acceptToken(Glob, pos);
}, { contextual: true });
const heredoc = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(HeredocStartIdentifier)) {
        const indented = input.next == 126; /* ~ */
        if (indented)
            input.advance();
        gobbleWhitespace(input);
        const quote = input.next == 39 /* ' */ || input.next == 34 /* " */ || input.next == 96 /* ` */
            ? input.next
            : undefined;
        if (!quote && isWhitespace(input.peek(-1)))
            return;
        if (quote)
            input.advance();
        if (input.next == 92 /* \\ */ && (isWhitespace(input.peek(-1)) || isWhitespace(input.advance())))
            return;
        if (!isIdentifierChar(input.next))
            return;
        for (;;) {
            input.advance();
            if (!isIdentifierChar(input.next))
                break;
        }
        if (quote) {
            if (input.next != quote)
                return;
            input.advance();
        }
        input.acceptToken(HeredocStartIdentifier);
        return;
    }
    if (!(stack.context instanceof Context))
        return;
    if (input.next == 10 /* \n */ &&
        heredocQueue.length &&
        heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos &&
        (stack.canShift(uninterpolatedHeredocStart) || stack.canShift(interpolatedHeredocStart))) {
        if (heredocQueue.slice(-1)[0]?.interpolating)
            input.acceptToken(interpolatedHeredocStart, 1);
        else
            input.acceptToken(uninterpolatedHeredocStart, 1);
        return;
    }
    if (stack.context.type !== 'heredoc' || !stack.context.inBody)
        return;
    if (stack.context.interpolating) {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        else if (input.next < 0) {
            input.acceptToken(HeredocEndIdentifier);
            return;
        }
    }
    else {
        const endCount = stack.context.atEnd(input);
        if (endCount) {
            input.acceptToken(HeredocEndIdentifier, endCount);
            return;
        }
        for (;;) {
            if (input.next < 0) {
                input.acceptToken(HeredocEndIdentifier);
                return;
            }
            if (input.next != 10 /* \n */) {
                input.advance();
                continue;
            }
            input.advance();
            const endCount = stack.context.atEnd(input);
            if (endCount) {
                input.acceptToken(StringContent);
                return;
            }
            input.advance();
        }
    }
}, { contextual: true });
const scanEscape = (input) => {
    const after = input.peek(1);
    // Restricted range octal character
    if (after >= 48 && after <= 55 /* 0-7 */) {
        let size = 2, next;
        while (size < 5 && (next = input.peek(size)) >= 48 && next <= 55)
            ++size;
        return size;
    }
    // Restricted range hexidecimal character
    if (after == 120 /* x */ && isHex(input.peek(2)))
        return isHex(input.peek(3)) ? 4 : 3;
    // Hexidecimal character
    if (after == 120 /* x */ && input.peek(2) == 123 /* { */) {
        // FIXME: There could be optional blanks at the beginning and end inside the braces.
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (!isHex(next))
                break;
        }
    }
    // This could be any named unicode character or character sequence.
    if (after == 78 /* N */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 0)
                break;
        }
    }
    // Octal character
    if (after == 111 /* o */ && input.peek(2) == 123 /* { */) {
        for (let size = 3;; ++size) {
            const next = input.peek(size);
            if (next == 125 /* } */)
                return size + 1;
            if (next < 48 || next > 55 /* not 0-7 */)
                break;
        }
    }
    return 2;
};
const interpolated = new ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.interpolating)
        return;
    let content = false;
    for (;; content = true) {
        if (heredocQueue.length &&
            (stack.context.type !== 'heredoc' ||
                heredocQueue.slice(-1)[0]?.newlinePos !== stack.context.newlinePos) &&
            input.next == 10 /* \n */) {
            break;
        }
        if ((stack.context.nestLevel == 0 && stack.context.atEnd(input)) ||
            input.next < 0 ||
            ((input.next == 36 /* $ */ || input.next == 64) /* @ */ &&
                (isVariableStartChar(input.peek(1)) ||
                    input.peek(1) == 123 /* { */ ||
                    (isSpecialVariableChar(input.peek(1), input.next == 64 /* @ */) &&
                        (stack.context.nestLevel > 0 || input.peek(1) !== stack.context.endDelimiter))))) {
            break;
        }
        if (stack.context.type.startsWith('quoteLike') &&
            stack.context.startDelimiter !== stack.context.endDelimiter &&
            input.next === stack.context.startDelimiter) {
            ++stack.context.nestLevel;
        }
        else if (stack.context.nestLevel > 0 && input.next === stack.context.endDelimiter) {
            --stack.context.nestLevel;
        }
        else if (input.next == 92 /* \\ */) {
            const escaped = scanEscape(input);
            if (escaped) {
                if (content)
                    break;
                else {
                    input.acceptToken(EscapeSequence, escaped);
                    return;
                }
            }
        }
        else if (!content &&
            (input.next == 91 /* [ */ ||
                input.next == 123 /* { */ ||
                (input.next == 45 /* - */ &&
                    input.peek(1) == 62 /* > */ &&
                    (input.peek(2) == 91 /* [ */ || input.peek(2) == 123))) /* { */ &&
            stack.canShift(afterInterpolation)) {
            input.acceptToken(afterInterpolation);
            return;
        }
        else if (!content &&
            input.next == 58 /* : */ &&
            input.peek(1) == 58 &&
            (stack.canShift(packageNamePart) || stack.canShift(afterPackageName))) {
            let pos = 2, ch;
            while (isIdentifierChar((ch = input.peek(pos))))
                ++pos;
            if (ch == 58 && input.peek(pos + 1) == 58)
                input.acceptToken(packageNamePart);
            else
                input.acceptToken(afterPackageName);
            return;
        }
        input.advance();
    }
    if (content)
        input.acceptToken(InterpolatedStringContent);
}, { contextual: true });
// Note that the paired delimiters enabled by the extra_paired_delimiters
// feature are not dealt with by the quote-like tokenizers.
const quoteLikeOperator = new ExternalTokenizer((input, stack) => {
    if (!(stack.context instanceof Context) || !stack.context.type.startsWith('quoteLike'))
        return;
    if (!stack.context.startDelimiter) {
        const haveWhitespace = isWhitespace(input.next);
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (stack.canShift(QuoteLikeStartDelimiter) && nextChar >= 0 && (!haveWhitespace || nextChar !== 35)) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
        return;
    }
    if (stack.canShift(QWElement) && isWhitespace(input.next))
        gobbleWhitespace(input);
    if (stack.canShift(QuoteLikeSeparatorDelimiter) &&
        stack.context.startDelimiter === stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeSeparatorDelimiter, 1);
        return;
    }
    else if (stack.canShift(QuoteLikeEndDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter &&
        input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (stack.canShift(QuoteLikeStartDelimiter) &&
        stack.context.type === 'quoteLike&regex' &&
        stack.context.startDelimiter !== stack.context.endDelimiter) {
        let pos = 1;
        let nextChar = input.next;
        while (isWhitespace(nextChar))
            nextChar = input.peek(pos++);
        if (nextChar === stack.context.startDelimiter) {
            input.acceptToken(QuoteLikeStartDelimiter, pos);
            return;
        }
    }
    if (input.next === stack.context.endDelimiter) {
        input.acceptToken(QuoteLikeEndDelimiter, 1);
        return;
    }
    if (input.next >= 0) {
        if (stack.canShift(StringContent)) {
            while (input.next >= 0 &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(StringContent);
            return;
        }
        else if (stack.canShift(QWElement)) {
            while (input.next >= 0 &&
                !isWhitespace(input.next) &&
                (stack.context.nestLevel > 0 ||
                    input.next !== stack.context.endDelimiter ||
                    (input.next === stack.context.endDelimiter && input.peek(-1) == 92))) {
                if (stack.context.startDelimiter !== stack.context.endDelimiter) {
                    if (input.next === stack.context.startDelimiter)
                        ++stack.context.nestLevel;
                    if (input.next === stack.context.endDelimiter)
                        --stack.context.nestLevel;
                }
                input.advance();
            }
            input.acceptToken(QWElement);
            return;
        }
    }
}, { contextual: true });
const regex = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(patternMatchStart) && input.next == 47 /* / */) {
        const divisionToken = stack.parser.nodeSet.types.find((t) => t.name == '/')?.id;
        if (typeof divisionToken === 'number' && !stack.canShift(divisionToken))
            input.acceptToken(patternMatchStart);
    }
    if (!(stack.context instanceof Context) || !stack.context.type.endsWith('regex'))
        return;
    if (stack.canShift(RegexOptions) &&
        stack.context.quoteLikeType &&
        isRegexOptionChar(input.next, stack.context.quoteLikeType)) {
        while (input.next >= 0 && isRegexOptionChar(input.next, stack.context.quoteLikeType))
            input.advance();
        input.acceptToken(RegexOptions);
        return;
    }
    if (stack.canShift(regexEnd)) {
        input.acceptToken(regexEnd);
        return;
    }
}, { contextual: true });
const pod = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(PodDirective)) {
        if ((input.peek(-1) == 10 /* \n */ || input.peek(-1) < 0) &&
            input.next == 61 /* = */ &&
            isASCIILetter(input.peek(1))) {
            while (input.next >= 0 && input.next != 10)
                input.advance();
            input.acceptToken(PodDirective);
            return;
        }
    }
    if (stack.canShift(PodContent)) {
        while (input.next >= 0) {
            if (input.next != 10) {
                input.advance();
                continue;
            }
            input.advance();
            if (input.peek(0) == 61 /* = */ &&
                input.peek(1) == 99 /* c */ &&
                input.peek(2) == 117 /* u */ &&
                input.peek(3) == 116 /* t */ &&
                (input.peek(4) == 10 || input.peek(4) < 0))
                break;
        }
        input.acceptToken(PodContent);
        return;
    }
    if (stack.canShift(PodCut)) {
        if ((input.peek(-1) == 10 || input.peek(-1) < 0) &&
            input.peek(0) == 61 /* = */ &&
            input.peek(1) == 99 /* c */ &&
            input.peek(2) == 117 /* u */ &&
            input.peek(3) == 116 /* t */ &&
            (input.peek(4) == 10 || input.peek(4) < 0)) {
            input.acceptToken(PodCut, 4);
            return;
        }
    }
});
const endData = new ExternalTokenizer((input, stack) => {
    if (stack.canShift(endDataBlock)) {
        while (input.advance() >= 0)
            ;
        input.acceptToken(endDataBlock);
    }
});

// This file was generated by lezer-generator. You probably shouldn't edit it.
const spec_Identifier = {__proto__:null,q:85, qq:91, __FILE__:121, __LINE__:123, __PACKAGE__:125, __SUB__:127, qw:143, qx:165, m:169, qr:177, s:181, tr:185, y:187, our:209, state:211, my:213, local:215, sub:219, prototype:235, package:241, use:253, no:255, if:263, lib:267, subs:271, feature:275, require:281, constant:285, parent:289, base:291, async:299, return:307, unless:309, while:311, until:313, for:315, foreach:317, elsif:323, else:327, continue:337, BEGIN:355, UNITCHECK:357, CHECK:359, INIT:361, END:363, __END__:373, __DATA__:375, next:379, last:381, redo:383, x:393, lt:407, gt:409, le:411, ge:413, eq:417, ne:419, cmp:423, isa:425, and:437, or:439, xor:441, not:449, fork:457, getpid:459, time:461, times:463, wait:465, wantarray:467, grep:473, map:475, join:477, sort:479, unpack:481, bless:493, print:497, say:499, printf:501, STDIN:503, STDERR:505, STDOUT:507, exec:511, system:513, SUPER:517, eval:881, do:541, goto:545, push:553, unshift:555, splice:557, pop:561, shift:563, each:567, values:569, keys:571};
const parser = LRParser.deserialize({
  version: 14,
  states: "#IOQ`Q!1hOOP(QOpOOO(YQ!LsO'#J[OOQq'#J['#J[OOO#t'#J^'#J^O+nO!!^O'#DVO,hO! pO'#DXOOO#t'#Ja'#JaO,oO!!^O'#DYO,wQ!LsO'#J]OOQ'y'#J]'#J]O0nQ!LsO'#DcO3xQNYO'#DbOOQq'#Jc'#JcO3}OpO'#DgOOQ'y'#Jd'#JdOOQq'#Je'#JeOOQq'#Jf'#JfOOQq'#Jg'#JgOOQq'#Jh'#JhOOQq'#Di'#DiO4SQ!LsO'#DiO?bQ#${O'#EfOBeQ!LsO'#JbOCRQ!&bO'#DrOOO#t'#Jl'#JlOHbO!!^O'#DtOOQq'#Ji'#JiOHjQNYO'#DwOHuQ!&bO'#DyONUQ!1hO'#EvO!%oQ!&bO'#HRO!%vQ!LsO'#KcO!({O! pO'#EOOOO#t'#Jn'#JnO!)SO!!^O'#EPOOO#t'#Jo'#JoO!)[O!!^O'#ERO!)dOMhO'#ETOOO#t'#Jp'#JpO!)iO!!^O'#EVOOO#t'#Jq'#JqO!)qO!!^O'#EXOOO#t'#Js'#JsOOO#t'#Jt'#JtO!)yO!!^O'#EZO!*RQNYO'#E^O!*^QNYO'#E`O!*iQNYO'#EbO!*wQNYO'#EdOOQt'#Jv'#JvOOQt'#Jw'#JwOOQt'#Jx'#JxOOQt'#Jy'#JyOOQt'#Ju'#JuO!+hQN^O'#EgOOQp'#J|'#J|OOQp'#KP'#KPO!+oQNYO'#EwOOQp'#KR'#KROOQp'#KS'#KSO!,YQ$ItO'#E}O!+tQ$ItO'#E}OOQ'x'#KV'#KVOOQp'#K['#K[O!,jQNYO'#F]O!,oQNZO'#KbO!,}QNZO'#FeOOQp'#Kd'#KdO!-hQNYO'#ElO!-xQNYO'#FfOOQ'y'#Ke'#KeO!3ZQ!&cO'#FjOOQ'x'#Kh'#KhOOQ'x'#Ki'#KiOOQ'x'#Kj'#KjOOQ'x'#Kk'#KkOOQ'x'#Kl'#KlO!3wQNYO'#FiO!4]QNYO'#FqO!4]QNYO'#FvO!4]QNYO'#FwO!4bQNYO'#GPO!4]QNYO'#F{O!4sQ$ItO'#F}O!5[Q!1iO'#GPO!<fQNZO'#GRO!,}QNZO'#GQOOQp'#Kp'#KpOOQp'#Kq'#KqOOQp'#Kr'#KrOOQp'#Ks'#KsOOQp'#Kt'#KtO!<qQNYO'#GSOOQ3O'#GY'#GYOOQ3O'#GZ'#GZO!<vO,UO'#G[OOQ7|'#Kv'#KvOOQ7|'#Kw'#KwO!<{Q!6fO'#G]OOQ3O'#KO'#KOOOQ'x'#LY'#LYO!=QQ!&bO'#HRO!=QQ!&bO'#HRO!=QQ!&bO'#HVOOQq'#LZ'#LZOOQq'#L['#L[OOQq'#L]'#L]OOQq'#L^'#L^OOQq'#L_'#L_OOQq'#L`'#L`O!=XQ!LsO'#HXO!@mQ#${O'#H`OOQ'x'#Lb'#LbOOQ'x'#Lc'#LcOOQ'x'#Ld'#LdOOQ'x'#Le'#LeOOQ'x'#Lf'#LfOOQ'x'#La'#LaO!CeQ!&bO'#HaO!MzQ!&bO'#HaO#%_Q!&bO'#HhO!CeQ!&bO'#HgOOQq'#Hi'#HiOOQp'#Lg'#LgO#%fQNYO'#HkOOQ'y'#Lj'#LjOOQ'y'#Lk'#LkOOQ'y'#Ll'#LlO#.^Q#${O'#HmOOQ'y'#Lr'#LrOOQ'y'#Ls'#LsO#.tQ#${O'#HtOOQp'#Lu'#LuO#/RQNYO'#HzO#/ZQNYO'#HzO!<qQNYO'#H}O!=QQ!&bO'#IPO#/`OMxO'#IQOOQ'y'#IS'#ISO#6rQ#${O'#IROOQ'y'#Lw'#LwO#>vQ#${O'#ITOOQ'x'#Lx'#LxO#E]Q!&bO'#IVOOQp'#Lz'#LzOOQp'#L{'#L{OOQp'#L|'#L|OOQp'#Ly'#LyO#EdQNYO'#IZOOQq'#MP'#MPOOQq'#MQ'#MQOOQq'#MO'#MOO#EoQ!LsO'#I_OOQp'#MT'#MTOOQp'#MU'#MUOOQp'#MV'#MVOOQp'#MS'#MSO#IZQNYO'#IbOOQq'#Jb'#JbO#IlQNYO'#D`OOQ3O'#I{'#I{Q`Q!1hOOO#IwO$fO'#CtO#JPO! pO'#CuPOOO)CD})CD}O#JWQ!&bO,5:hO$ xQN^O,5>cO$']Q!&bO,5:iOOOO'#Ii'#IiO$'dOMhO'#J_O$'lO#tO,59qO$'tO#tO,59qO$'yO!$fO'#J[O$)aO!bO'#CyOOQ'y,59s,59sO$)fO! pO,59sO$)mO!$fO'#JZOOO%|'#JZ'#JZOOO%|'#Ig'#IgO$*}O!$fO,59tO$+UO#tO,59tO$ dQN^O,5>cO$+ZQN[O'#IlO$+cQNYO,59}O$+kQN[O,59|OOQ'y,5:R,5:RO!4]QNYO,5>hO!=QQ!&bO,5:YO$+sQN[O'#IrO$+{Q!&cO,5;eOOQp,5<d,5<dO$1eQ!1hO,5?cO$1lQ#${O'#EfO$2PQ!LrO,5@}OCRQ!&bO'#DrO$4oQNYO,5:^O$4tQ!&bO'#DzO!+SQN^O'#EgO$5OQNYO'#ElO$5ZO#tO'#DvOOQq,5:`,5:`O$5cO#tO,5:`OOQq,5:c,5:cO#JWQ!&bO,5:cO$5hQ!LrO'#JjO$5rQNYO,5:eO$5wQ!LsO'#JjO$6OQNYO,5:fO$6TQNZO'#KxOOQq'#Ky'#KyOOQq'#Kz'#KzOOQq'#K{'#K{O$6_QNZO'#G`OOQ3O'#Kx'#KxOOQ3O'#Iq'#IqO$6lQ!1hO,5;bOOQ3P,5;b,5;bO$4tQ!&bO,5:fO$8aQ!LsO,5=mO$:cQ!&bO'#KgO!,}QNZO,5<TO!=QQ!&bO,5=OOOQ'x'#K|'#K|O!=QQ!&bO,5=QO$?oQ!&bO,5=TOOQ'x'#K}'#K}OOQ'x'#LO'#LOOOQ'x'#LP'#LPOOQ'x'#LQ'#LQO!=QQ!&bO'#IyO$BrQ!LsO,5=TOOQ'x'#LR'#LROOQ'x'#LS'#LSO!=QQ!&bO'#IzO$C`Q!LsO,5=TOOQ'x'#LT'#LTOOQ'x'#LU'#LUOOQ'x'#Gy'#GyOOQ'x'#LV'#LVOOQ'x'#LW'#LWOOQ'x'#LX'#LXO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TO!=QQ!&bO,5=TOOQq,5=q,5=qO$C|Q!&bO,5>sOOQq,5:j,5:jO$DTO! pO,5:jO$D[O!$fO,5:kO$DfO#tO,5:kO$DkO!$fO,5:mO$DuO#tO,5:mO$DzO! pO,5:oO$ERO!$fO,5:qO$E]O#tO,5:qO$EbO!$fO,5:sO$EoO#tO,5:sO$EtO#tO,5:uO$EyO#tO,5:uOOQq,5:x,5:xO#JWQ!&bO,5:xOOQq,5:z,5:zO#JWQ!&bO,5:zOOQq,5:|,5:|O#JWQ!&bO,5:|O$NOQ#${O,5>SO$FOQ#${O,5>SOOQq,5;O,5;OO#JWQ!&bO,5;OO% WQN^O,5;ROOQq,5;R,5;RO% _QNYO,5<QO% dQ$IuO'#EyO% uQ$IuO,5;cO%!TQ(JRO'#EyO%'fQ(JRO,5;iO%,|Q!&bO'#KUO%-TQNYO,5;nOOQp'#KW'#KWO%-]QNYO,5;pOOQp'#KX'#KXO%-nQNYO,5;rOOQq'#KZ'#KZO%-yQNZO,5;tO!,}QNZO,5;vOOQp'#K]'#K]O%.^QNYO,5;yOOQq'#K^'#K^OOQq'#K_'#K_O%.kQ$IuO,5;{O%/OQNZO'#EyO!,}QNZO,5;wOOQ'y'#Jk'#JkO%/ZQ!&cO'#IuO%/}QNZO,5@|O%0]OqO'#E{OOQ3P'#KQ'#KQOOQ3O,5<P,5<PO%0hQ0>YO'#EnOOQq'#Er'#ErO%0oQNYO'#EpOOQq'#Ip'#IpO%0wQNYO,5;WOOQq'#Fh'#FhO%1PQNZO,5<QO!<qQNYO,5<nO%1bQ!1hO'#EvOOQq,5;W,5;WO%1rQNYO,5;WO!<qQNYO,5;WO%1zQNYO,5;WO%4iQ!LsO'#KcO%5]QNZO'#KfOOQq,5<U,5<UOCRQ!&bO'#DrO!<qQNYO,5<]O!<qQNYO,5<bO!<qQNYO,5<cO!4]QNYO,5<cO!4]QNYO,5<gO%5}Q$ItO,5<iO%=mQ!1iO,5<kO!<qQNYO,5<gO%=tQ!&cO,5<hO!<qQNYO,5<iO!4]QNYO,5<iO%>OQNYO,5<iO%>TQNYO,5<iOOQp'#Ko'#KoO!<qQNYO'#FyOOQ3O,5<k,5<kO%6fQ!1iO,5<kO%>fQNYO'#IwOOQq-E<u-E<uOOQ3O,5<l,5<lOOQ3O,5<n,5<nO%>kO,UO,5<vOOQ3O,5<w,5<wO%>pQ!LsO,5=mO%@rQ!LsO,5=qO%DTQNYO,5=sOOQq,5=z,5=zO%DYQ!LsO'#KTOOQq'#FR'#FROOQq,5={,5={O!-}Q!&bO,5>iOOQq,5>R,5>RO%EYQNYO'#DzOOQq'#Li'#LiOOQq'#Lh'#LhO%EpQNYO'#LhOOQq,5>V,5>VO!=QQ!&bO'#LiO%EwQ#${O'#J[O$1lQ#${O'#EfO%MpQ!&bO'#DrOOQ'y'#Ln'#LnOOQ'y'#Lo'#LoOOQ'y'#Lp'#LpOOQ'y'#Lq'#LqOOQq'#Lm'#LmOOQq,5>X,5>XO&%YQ#${O'#LmO&/tQ#${O'#J[O&0UQ!&bO'#DrOOQq'#Lt'#LtO&5eQ#${O'#LtOOQq,5>`,5>`O&5rQ!LsO'#EyO&9ZQ!LsO,5>fO&<oQNYO,5>fO&>tQ!LsO,5>kOOQq,5>l,5>lO&@ZO`O,5>lOOQq,5>m,5>mOOQq,5>o,5>oO&HPQ#${O,5>qO&JsQ!LsO,5>qO%-TQNYO'#L}O&LSQNYO'#L}OOQq,5>u,5>uOOQq'#MR'#MRO&L[QNYO'#MROOQq,5>y,5>yOOQq'#MW'#MWO&LdQNYO'#MWOOQq,5>|,5>|OOQq,59z,59zO#JWQ!&bO,59zOOQ3O-E<y-E<yOOO%},59`,59`O&LrOpO,59`O&LwO! pO,59aOOO%},59a,59aO' eQ!LrO1G0SO#JWQ!&bO1G0SO' lQ!&bO1G0TOOQq'#Hy'#HyO' sQ!LsO1G3}O'%XQNYO1G3}O'%^Q#$zO1G0TO''lQ!LrO1G0TOOOO-E<g-E<gO''sO!!^O,5?yOOO#t'#Ik'#IkO'(OO#tO1G/]OOQ'y1G/]1G/]O'(OO#tO1G/]O'(WOMhO'#IhO'(]O!bO,59fO'(eOMhO,59mO'(yOMhO,59mO')ROMhO,59mO')^OMhO,59kO')xOMhO,59eOOQ'y1G/_1G/_OOO%|-E<e-E<eOOQ'y1G/`1G/`O')}O!$fO1G/`O')}O!$fO1G/`OOQp,5?W,5?WOOQp-E<j-E<jOOQq'#Dd'#DdOOQq1G/h1G/hOOQq1G4S1G4SO'*UQ!LsO1G/tOOQ'y,5?^,5?^OOQ'y-E<p-E<pO$6TQNZO'#IxOOQ3O'#Ix'#IxO'+eQ!1hO1G4}OOQq1G4}1G4}O'+lQ!&cO'#ImO',YQNYO,5@UPOQq1G6i1G6iOOQq1G/x1G/xOOO#t'#In'#InO',kO#tO,5:bOOQq,5:b,5:bOOQq1G/z1G/zO',sQ!LrO1G/}OOQq1G0P1G0POOQq1G0Q1G0QOOQ3O,5Ad,5AdOOQ3O,5<z,5<zO!,}QNZO,5<zO$6TQNZO,5<zOOQ3O-E<o-E<oOOQ3P1G0|1G0|O',zQNYO1G0QOOQq,5AR,5AROOQ3O1G1o1G1oO'-PQ!LsO1G2jO'.`Q!LsO1G2lO'2}Q!LsO1G2oO!=QQ!&bO1G2lO'5_Q!LsO,5?eOOQq-E<w-E<wO'8qQ!LsO,5?fOOQq-E<x-E<xO':QQ!LsO1G2oO'=aQ!LsO1G2oO'=nQ!LsO1G2oO'@}Q!LsO1G2oO'AbQ!LsO1G2oO'ETQ!LsO1G2oO'E[Q!LsO1G2oO'HqQ!LsO1G2oO'HxQ!LsO1G2oO'LUQ!LsO1G2oO'LfQ!LsO1G2oO'LvQ!LsO1G2oO'NVQ!LrO1G4_O!=QQ!&bO1G4_OOQq1G0U1G0UO'N^O#tO1G0VOOQq1G0V1G0VO'NcO!$fO1G0VO'NjO!$fO1G0VO'NtO#tO1G0XO'NyO&jO1G0XO( RO!$fO1G0XO( YO!$fO1G0XO( dO&jO1G0ZO( lO! pO1G0ZO( sO#tO1G0]O( xO&jO1G0]O(!QO!$fO1G0]O(!XO!$fO1G0]OOO%|'#Jr'#JrO(!cO!!^O'#JrO(!kO#tO1G0_O(!sO!$fO1G0_O(!}O!$fO1G0_O(#XO!$fO1G0_O(!kO#tO1G0aO(#fO#tO1G0aO(#kQ!LrO1G0dO(#rQ!LrO1G0fO(#yQ!LrO1G0hO($QQ#${O,5;eO(&oQ!LrO1G0jO0]QNYO'#DcOOQp'#J{'#J{O(&vQN^O'#J{O('XQNYO'#JzO('dQNYO1G0mO%1PQNZO1G1lO('iQ$IuO,5;eOOQ3O1G0}1G0}O('zQNZO1G0}O((VQ(JRO,5;eOOQ3O1G1T1G1TO!,}QNZO1G1TO%'iQ!&cO1G1TO(-hQ!LrO,5@pOOQp,5@p,5@pO(-rQNYO1G1YO!,}QNZO1G1[OOQq'#KY'#KYO!,}QNZO1G1^OOQ3O1G1`1G1`O!,}QNZO1G1`OOQ3O1G1b1G1bOOQp'#Ef'#EfO%-TQNYO1G1eO!,}QNZO1G1eOOQq'#Ka'#KaO%-]QNYO'#KaO(-|QNZO'#K`O!,}QNZO1G1gO(.[QNYO1G1gOOQ3O1G1c1G1cOOQq,5?a,5?aOOQq-E<s-E<sOOOq'#Is'#IsO(.aOqO,5;gOOQ3P,5;g,5;gOOQq,5;Y,5;YO(.lQNYO,5;YO(.qQNYO,5:^O(.vQNZO,5;[OOQp'#J}'#J}O(/XQNYO,5;`OOQq-E<n-E<nO!<qQNYO1G0rO%1zQNYO1G0rO%0wQNYO1G1lOOQ3O1G1l1G1lO(/^QNZO1G1lO('zQNZO1G1lO%1zQNYO1G1lOOQ3O1G2Y1G2YO(/lQNYO'#EpO%1rQNYO1G0rOOQq1G0r1G0rO%1zQNYO1G0rO(/qQNZO,5AQO(0cQ!1hO1G1wO(7jQ!1hO1G1|O(>qQ!1hO1G1}O!<qQNYO1G1}O!<qQNYO1G2RO%=tQ!&cO1G2SO!<qQNYO1G2TO!4]QNYO1G2TO(EuQNYO1G2TO(EzQNYO1G2TOOQ3O1G2V1G2VO(F]Q!1iO1G2VO(MdQ!1hO1G2RO)&hQ!LsO1G2SO!,}QNZO1G2SO)&rQ!1hO1G2TO)-vQNYO1G2TOOQ3P,5<e,5<eOOQ3O1G2b1G2bOOQq1G3_1G3_O)-{Q#${O'#ImO)1XQ!LsO,5@oO)4]Q!LsO'#KbOOQq1G4T1G4TO$4tQ!&bO,5:fP!=QQ!&bO,5BSO)7nQNYO,5BSO)8bQ!LsO,5BTO);`Q!LsO,5@UO)>dQNYO,5:^OCRQ!&bO,5BXOOQq,5BX,5BXOHuQ!&bO,5:hO)>iQ!&bO,5:iOOQq,5B`,5B`O)D`Q#$zO,5B`O)FXQNYO,5:^OCRQ!&bO,5B`OOQq1G4Q1G4QOOQp'#H{'#H{O)F^QNYO1G4QOOQq1G4W1G4WO!CeQ!&bO,5BiO%-TQNYO,5BiO)FfQNYO,5BmO)FkQNYO,5BrO)FpQ!LrO1G/fOOO%}1G.z1G.zOOO%}1G.{1G.{OOQq7+%n7+%nO)FwQ!LsO'#LhO)IvQ!LrO7+%nO)I}Q#$zO7+%oO)L]Q!LrO7+%oOOQq7+)i7+)iO)LdQNYO7+)iOOQq7+%o7+%oO)LiOMhO'#IjOOO#t'#Ij'#IjO)LqO!!^O1G5eOOO#t-E<i-E<iOOQ'y7+$w7+$wO)L|O#tO7+$wO)MUOMjO,5?SOOO!b-E<f-E<fO)M^OMhO1G/XO)McOMhO1G/XO)MwOMhO1G/VO)NcOMhO1G/XO)NkOMhO1G/VO)NpOMhO1G/VO)NuOMjO1G/POOQ'y7+$z7+$zO)N}O!$fO7+$zOOQ3O,5?d,5?dOOQ3O-E<v-E<vOOQq7+*i7+*iO* UQ!LsO,5?XOOQq-E<k-E<kOOO#t-E<l-E<lOOQq1G/|1G/|OOQq7+%i7+%iOOQ3O1G2f1G2fO!,}QNZO1G2fO*!UQ!LsO7+%lO)0vQNZO,5@oO*(vQ!LsO7+(WO!=QQ!&bO7+)yO**VQ!LsO7+)yOOQq7+%q7+%qO*+fO#tO7+%qO*+kO!$fO7+%qO*+rO&jO7+%sOOQq7+%s7+%sO*+uO&jO7+%sO*+zO#tO7+%sO*,PO!$fO7+%sOOQq7+%u7+%uO*,WO&jO7+%uO*,]O&jO7+%uO*,eO&jO7+%wOOQq7+%w7+%wO*,hO&jO7+%wO*,mO#tO7+%wO*,rO!$fO7+%wOOO%|,5@^,5@^O*,yO#tO,5@^O*-OO!$fO7+%yO*-YO#tO7+%yO*-_O&jO7+%yO*-gO!$fO7+%yO(!kO#tO7+%yO(!}O!$fO7+%yO*-nO#tO7+%{O(!kO#tO7+%{OOQq7+&O7+&OOOQq7+&Q7+&QOOQq7+&S7+&SOOQq7+&U7+&UO*-sQNYO,5@gO*-xQN^O'#IoO*.VQNYO,5@fOOQq7+&X7+&XO%0wQNYO7+'WOOQ3O7+'W7+'WO(/^QNZO7+'WO('zQNZO7+'WO%1zQNYO7+'WOOQ3O7+&i7+&iOOQ3O7+&o7+&oO!,}QNZO7+&oO*.bQ(JRO7+&tOOQ3O7+&v7+&vOOQ3O7+&x7+&xOOQ3O7+&z7+&zO#JWQ!&bO7+'POOQ3O7+'P7+'PO*.uQNYO,5@{O*.zQNZO'#ItO*/_QNZO,5@zOOQ3O7+'R7+'RO*/mQNZO7+'ROOOq-E<q-E<qOOQ3P1G1R1G1ROOQq1G0t1G0tOOQq1G0y1G0yOOQq1G0v1G0vO*/}Q08QO'#EnOOQp1G0z1G0zOOQq7+&^7+&^O%1zQNYO7+&^O!<qQNYO7+&^O(/^QNZO7+'WO%1zQNYO7+'WOOQp'#Km'#KmO!4]QNYO'#FrOOQ3O'#Iv'#IvO*0VQ!1hO7+'cOOQp'#Kn'#KnO!<qQNYO'#FtOOQ3O7+'c7+'cO*7^Q!1hO7+'hOOQ3O7+'h7+'hOOQ3O7+'i7+'iO*>eQ!1hO7+'iO*EiQ!1hO7+'mO)&hQ!LsO7+'nO!,}QNZO7+'nO*LmQ!1hO7+'oO!<qQNYO7+'oO!4]QNYO7+'oO+%qQNYO7+'oOOQ3O7+'q7+'qOOQ3O7+'m7+'mO#JWQ!&bO7+'nO+%vQNYO7+'nOOQ3O7+'o7+'oO+%{Q#${O'#IuO+(sQ!LsO,5@|O+,UQNYO1G0QO+,ZQ!LsO1G7nOOQq1G7n1G7nO#JWQ!&bO1G7nOOQq1G7s1G7sO+/lQNYO1G7sO+/qQ!LrO1G0SO+0OQ!LrO1G0TO+0]QNYO1G7zOOQq1G7z1G7zO+0bQ!LsO7+)lOOQq1G8T1G8TO$:cQ!&bO1G8TOOQq1G8X1G8XOOQq1G8^1G8^OOQq7+%Q7+%QOOQq<<IY<<IYOOQq<<IZ<<IZO+3vQ!LsO<<MTOOO#t,5?U,5?UOOO#t-E<h-E<hOOQ'y<<Hc<<HcOOO!b1G4n1G4nOOO%|7+$s7+$sO+7[OMhO7+$sO+7aOMhO7+$qO+7fOMhO7+$qO+7kOMhO7+$sO+8POMhO7+$qOOO%|7+$q7+$qOOO%|'#C}'#C}OOO%|7+$k7+$kOOQ'y<<Hf<<HfOOQ3O7+(Q7+(QO+;QQ!LsO1G/xO+;eQ!LsO<<MeOOQq<<I]<<I]OOQq<<I_<<I_O+<tO&jO<<I_O+<yO&jO<<I_OOQq<<Ia<<IaO+=RO&jO<<IaOOQq<<Ic<<IcO+=WO&jO<<IcO+=]O&jO<<IcOOO%|1G5x1G5xO+=eO#tO<<IeO+=jO&jO<<IeO+=rO!$fO<<IeOOQq<<Ie<<IeO+=mO&jO<<IeO+=yO!$fO<<IeO+>TO#tO<<IgO+>YO#tO<<IgOOQp1G6R1G6ROOQp,5?Z,5?ZOOQp-E<m-E<mO('zQNZO<<JrO%1zQNYO<<JrO(/^QNZO<<JrOOQ3O<<Jr<<JrO%1zQNYO<<JrOOQ3O<<JZ<<JZOOQ3O<<J`<<J`O!,}QNZO<<J`O%'iQ!&cO<<J`O+>_Q!&cO<<J`O+>oQ!LsO<<JkOOQq1G6g1G6gOOQq,5?`,5?`OOQq-E<r-E<rO!,}QNZO<<JmO!<qQNYO<<IxOOQq<<Ix<<IxO!<qQNYO,5<^OOQ3O-E<t-E<tOOQ3O<<J}<<J}OOQ3O,5<`,5<`OOQ3O<<KS<<KSOOQ3O<<KT<<KTOOQ3O<<KX<<KXO#JWQ!&bO<<KYO+>yQNYO<<KYOOQ3O<<KZ<<KZO+?OQ!1hO<<KZO!<qQNYO<<KZO!4]QNYO<<KZO+>oQ!LsO<<KYO!<qQNYO<<KYOOQq7+%l7+%lO+FSQ!LrO7+-YOOQq7+-_7+-_OOQq7+-f7+-fOOQq<<MW<<MWO+FZQNYO7+-oO+F`Q!LsO1G/xO+I_Q!LsO1G/xOOQqANBoANBoOOO%|<<H_<<H_OOO%|<<H]<<H]O+L^OMhO<<H]O+LcOMhO<<H_O+LhOMhO<<H]OOQqAN>yAN>yO+LmO&jOAN>yOOQqAN>{AN>{OOQqAN>}AN>}O+LrO&jOAN>}O+LwO&jOAN?POOQqAN?PAN?PO+LzO&jOAN?PO+MPO#tOAN?PO+MUO!$fOAN?PO+M]O&jOAN?RO+MeO#tOAN?ROOQ3OAN@^AN@^O%1zQNYOAN@^O('zQNZOAN@^OOQ3OAN?zAN?zO!,}QNZOAN?zO%'iQ!&cOAN?zOOQ3OAN@VAN@VOOQ3OAN@XAN@XOOQqAN?dAN?dOOQ3O1G1x1G1xO+>oQ!LsOAN@tO!<qQNYOAN@tOOQ3OAN@uAN@uO+MjQ!1hOAN@uO!<qQNYOAN@uO#JWQ!&bOAN@tOOQ3OAN@tAN@tOOQq<=!t<=!tOOQq<=#Z<=#ZOOO%|AN=wAN=wOOO%|AN=yAN=yO,&nOMhOAN=wOOQqG24eG24eOOQqG24iG24iOOQqG24kG24kO,&sO&jOG24kO,&xO&jOG24kOOQqG24mG24mO,'QO&jOG24mO,'VO&jOG24mO('zQNZOG25xOOQ3OG25xG25xOOQ3OG25fG25fO!,}QNZOG25fO#JWQ!&bOG26`OOQ3OG26`G26`OOQ3OG26aG26aO,'_Q!1hOG26aO,.cQ!LrOG26`OOO%|G23cG23cOOQqLD*VLD*VO,.jO&jOLD*VOOQqLD*XLD*XO,.oO&jOLD*XOOQ3OLD+dLD+dOOQ3OLD+QLD+QO,.tQ!LrOLD+zOOQ3OLD+{LD+{O!<qQNYOLD+zOOQq!$'Mq!$'MqOOQq!$'Ms!$'MsO!<qQNYO!$( fOOQ3O!$( f!$( fOOQ3O!)9EQ!)9EQO,.{QNYO'#E^O#%fQNYO'#HkO#JWQ!&bO'#IPO,/WQ#${O'#IRO,/zQ#${O'#ITO,0nQ!&bO'#IVO,0uQNYO'#D`O#JWQ!&bO'#HRO#JWQ!&bO,5:YO,1QQ#${O'#EfO,3oQ!LsO'#JjO#JWQ!&bO,5=OO#JWQ!&bO,5=QO,4fQ!&bO,5=TO#JWQ!&bO'#IyO,6|Q!LsO,5=TO#JWQ!&bO'#IzO,7jQ!LsO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO#JWQ!&bO,5=TO,8WQ!LsO'#KcO,=uQ!LsO,5=mO,>fQ!LsO'#KTO,>yQ#$zO'#J[O,FsQ#${O'#J[O,I[Q#${O'#J[O,KdQ!LsO,5>kO,LaQ#${O,5>qO,NnQ!LsO,5>qO- eQ#$zO1G0TO-#vQ!LsO1G/tO-$gQ!LsO1G2jO-%WQ!LsO1G2lO-(mQ!LsO1G2oO#JWQ!&bO1G2lO-(tQ!LsO,5?eO-)hQ!LsO,5?fO-*_Q!LsO1G2oO--UQ!LsO1G2oO--cQ!LsO1G2oO-0YQ!LsO1G2oO-0mQ!LsO1G2oO-3vQ!LsO1G2oO-3}Q!LsO1G2oO-6zQ!LsO1G2oO-7RQ!LsO1G2oO-9uQ!LsO1G2oO-:VQ!LsO1G2oO-:gQ!LsO1G2oO#JWQ!&bO1G4_O-;WQNYO,5:^O#JWQ!&bO,5BSO-;]Q!LrO,5BTO-;jQNYO,5:^O-;oQNYO,5:^O-;tQ!LsO7+(WO#JWQ!&bO7+)yO-<eQ!LsO7+)yO-=[Q!LrO1G/xO-=fQ!LsO1G/xO-@eQ!LsO<<MeO-A[Q!LsO'#JbO-FlQ!&bO'#HRO#JWQ!&bO'#HRO#JWQ!&bO'#HVO-K|Q#${O'#H`O.(UQ#${O'#HmO.(lQ#${O'#HtO.(yQ!&bO,5>sOCRQ!&bO'#DrO!=QQ!&bO'#LiO%MpQ!&bO'#DrO&0UQ!&bO'#DrO.)QQ!LrO1G4_O.)XQ!&bO,5BiO.)`QNYO,5:^O.)eQNYO,5:^O.)XQ!&bO'#HaO..sQ!&bO'#HaO.)XQ!&bO'#HgO%-TQNYO'#L}OCRQ!&bO'#DrOCRQ!&bO'#DrO..zQNYO'#IZ",
  stateData: "./u~OgOS'|OS'sPQ'tPQ~OQ]OR#dOS#kOT#}OU$OOd#SOjQOkROlROpfOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO#l!ZO#p#RO#r!]O#s!^O#w!aO$Q!bO$Z!fO$_!iO$`!kO$a!lO$b!mO$c!nO$d!oO$w!zO$x!{O$y!|O$z!}O${#OO%Q#TO%R#UO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO)i#QO*j$PO~O's$iO't$jO~Ov$mOw$nO!O$lOo(OX!Q(OX![(OX!c(OX!g(OX!o(OX!x(OX#T(OX#V(OX#X(OX#p(OX#w(OX$`(OX$a(OX$b(OX$c(OX$d(OX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX%z(OX&|(OX'q(OX!d(OXr(OXt(OX#e(OX~O^$qO'|$oO~OQ$xO[$xO]$xOj$sOkROlRO!T5RO#R4{O's$iO't$jO~O(S$uO~P+vO^$zO'|$oO~Ov$|Ov(PXw(PX!O(PX!Q(PX![(PX!c(PX!g(PX!o(PX!x(PX#T(PX#V(PX#X(PX#p(PX#w(PX$`(PX$a(PX$b(PX$c(PX$d(PX%X(PX%Z(PX%[(PX%^(PX%_(PX%`(PX%a(PX%b(PX%c(PX%d(PX%e(PX%f(PX%g(PX%h(PX%i(PX%j(PX%k(PX%l(PX%n(PX%o(PX%p(PX%q(PX%r(PX%s(PX%t(PX%z(PX&|(PX'q(PX!d(PXr(PXt(PX#e(PX~Oo$}Oo!VX!c(VX!g(VX!d(VX~Ov(VXw(VX!O(VX!Q(VX![(VX!o(VX!x(VX#T(VX#V(VX#X(VX#p(VX#w(VX$`(VX$a(VX$b(VX$c(VX$d(VX%X(VX%Z(VX%[(VX%^(VX%_(VX%`(VX%a(VX%b(VX%c(VX%d(VX%e(VX%f(VX%g(VX%h(VX%i(VX%j(VX%k(VX%l(VX%n(VX%o(VX%p(VX%q(VX%r(VX%s(VX%t(VX%z(VX&|(VX'q(VXr(VXt(VX#e(VX~P0]Oo%PO~OY%QO~Ov%ROw!]X!O!]X!Q!]X![!]X!c!]X!g!]X!o!]X!x!]X#T!]X#V!]X#X!]X#p!]X#w!]X$`!]X$a!]X$b!]X$c!]X$d!]X%X!]X%Z!]X%[!]X%^!]X%_!]X%`!]X%a!]X%b!]X%c!]X%d!]X%e!]X%f!]X%g!]X%h!]X%i!]X%j!]X%k!]X%l!]X%n!]X%o!]X%p!]X%q!]X%r!]X%s!]X%t!]X%z!]X&|!]X'q!]X!d!]Xr!]Xt!]X#e!]X~Oo%TO!c%SOQ&[XR&[XS&[XT&[XU&[Xj&[Xj&oXk&[Xl&[Xp&[Xp&oXv#mXx&[Xz&[X}&[X!O&[X!P&[X!Q&[X!R&[X!T&[X!X&[X!Y&[X![&[X!^&[X!_&[X!`&[X!a&[X!e&[X!g#YX!i&[X!l&[X!o&[X!t&[X!v&[X!x#YX!z&[X!|&[X#O&[X#P&[X#R&[X#T&[X#V&[X#X&[X#[&[X#]&[X#^&[X#_&[X#a&[X#p#YX#w#YX$`#YX$a#YX$b#YX$c#YX$d#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX%v&[X%w&[X%x&[X%z&[X%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X&|#YX'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'q#YX'x&[X(S&[X(a&[X*j&[Xt#YX~Ow%WO#e%VO~P7eOv(UXw(UX!O(UX!Q(UX![(UX!o(UX!x(UX#T(UX#V(UX#X(UX#p(UX%X(UX%Z(UX%[(UX%^(UX%_(UX%`(UX%a(UX%b(UX%c(UX%d(UX%e(UX%f(UX%g(UX%h(UX%i(UX%j(UX%k(UX%l(UX%n(UX%o(UX%p(UX%q(UX%r(UX%s(UX%t(UX%z(UX&|(UX'q(UX!d(UXr(UXt(UX#e(UX~O!c%SO!g(UX#w(UX$`(UX$a(UX$b(UX$c(UX$d(UX~P?lOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO!d(^P~O^%`O'|$oO~Oj%cOp%cOw%dO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$POr(^P~O%T%jO%U%kO%V%lOt(^P~P`OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~Ow%rO~PNfOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O#w!aO$`!kO$a!lO$b!mO$c!nO$d!oO%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO!c)VX!g)VX#p)VX'q)VX~O(a&kO~P+vO^&mO'|$oO~O^&oO'|$oO~O!x&qO~O^&rO'|$oO~O^&tO'|$oO~O^&vO'|$oO~Oj&xOw&yO!T$fO~Oj&zOw&{O!T$fO~Oj&|Op'OOw&}O!T$fO~Oj'QOw'RO!T$fO~OQ]OjROkROlRO!X'TO!e'SO~O#a!YO~P!+SOp'VO~Op'XO#n'cO#t'YO#w!aO#{'_O#}'aO~O#y']O$S'dO$U'fO$V'gO~P!+tOp'iO~O!c'kO!g'kO#p)UX'q)UX~O#p'nO'q'oO~O$w!zO$x!{O$y!|O$z!}O${#OO~Op'vOw'yO!e'qO#e'sO~P!-VO#a!YO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~O#w)YP$`)YP$a)YP$b)YP$c)YP$d)YP#p)YP'q)YP~P!-}O#w!aO$`!kO$a!lO$b!mO$c!nO$d!oO~O!e(RO~Ow'yO$a!lO$b!mO$c!nO$d!oO~Oj(^O!e([O#[!SO#]!TO#^!UO#_!VO$r(`O~O#p'nO$n(aO'q'oOQ$sXR$sXS$sXT$sXU$sXd$sXj$sXk$sXl$sXp$sXw$sXx$sXz$sX}$sX!O$sX!P$sX!Q$sX!R$sX!T$sX!X$sX!Y$sX![$sX!^$sX!_$sX!`$sX!a$sX!e$sX!i$sX!l$sX!o$sX!t$sX!v$sX!z$sX!|$sX#O$sX#P$sX#R$sX#T$sX#V$sX#X$sX#[$sX#]$sX#^$sX#_$sX#a$sX#l$sX#p$sX#r$sX#s$sX#w$sX$Q$sX$Z$sX$_$sX$`$sX$a$sX$b$sX$c$sX$d$sX$w$sX$x$sX$y$sX$z$sX${$sX%Q$sX%R$sX%v$sX%w$sX%x$sX%z$sX%|$sX%}$sX&O$sX&P$sX&Q$sX&R$sX&U$sX&V$sX&W$sX&X$sX&Y$sX&`$sX&b$sX&c$sX&d$sX&i$sX&j$sX&l$sX&x$sX&z$sX'O$sX'P$sX'Q$sX'S$sX'T$sX'V$sX'W$sX'X$sX'p$sX'x$sX(S$sX(a$sX)i$sX*j$sXt$sX%T$sX%U$sX%V$sX~Op(eO#p$uX'q$uX~Ow'yO~Oe(iO~O'z(jO~Ow%]O~PNfO!e(mOv%{Xw%{X!O%{X!Q%{X![%{X!c%{X!g%{X!o%{X!x%{X#T%{X#V%{X#X%{X#p%{X#w%{X$`%{X$a%{X$b%{X$c%{X$d%{X%X%{X%Z%{X%[%{X%^%{X%_%{X%`%{X%a%{X%b%{X%c%{X%d%{X%e%{X%f%{X%g%{X%h%{X%i%{X%j%{X%k%{X%l%{X%n%{X%o%{X%p%{X%q%{X%r%{X%s%{X%t%{X%z%{X&|%{X'q%{X!d%{Xr%{Xt%{X#e%{X~Ov&SX!c&SX!g&SX!x&SX#p&SX#w&SX$`&SX$a&SX$b&SX$c&SX$d&SX%X&SX%Z&SX%[&SX%^&SX%_&SX%`&SX%a&SX%b&SX%c&SX%d&SX%e&SX%f&SX%g&SX%h&SX%i&SX%j&SX%k&SX%l&SX%n&SX%o&SX%p&SX%q&SX%r&SX%s&SX%t&SX&|&SX'q&SX!d&SXr&SXt&SX#e&SX~P!-}OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e(RO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e(RO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~OwnO~P!HqOQ&[XR&[XS&[XT&[XU&[Xj&[Xk&[Xl&[Xp&[Xw&[Xx&[Xz&[X}&[X!O&[X!P&[X!Q&[X!R&[X!T&[X!X&[X!Y&[X![&[X!^&[X!_&[X!`&[X!a&[X!e&[X!i&[X!l&[X!o&[X!t&[X!v&[X!z&[X!|&[X#O&[X#P&[X#R&[X#T&[X#V&[X#X&[X#[&[X#]&[X#^&[X#_&[X#a&[X%v&[X%w&[X%x&[X%z&[X%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'x&[X(S&[X(a&[X*j&[X~Ov$|O~P!NROj(uOw%]O!OmO!e(wO!o(tO#a!YO%w(yO~OQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$POv(^Pw(^P!O(^P!Q(^P!c(^P!g(^P!o(^P!x(^P#T(^P#V(^P#X(^P#p(^P#w(^P$`(^P$a(^P$b(^P$c(^P$d(^P%X(^P%Z(^P%[(^P%^(^P%_(^P%`(^P%a(^P%b(^P%c(^P%d(^P%e(^P%f(^P%g(^P%h(^P%i(^P%j(^P%k(^P%l(^P%n(^P%o(^P%p(^P%q(^P%r(^P%s(^P%t(^P%z(^P&|(^P'q(^P!d(^Pr(^Pt(^P#e(^P~Oj(zOp({O!e(|O&e(}O&f)OO&g)PO~P#%}Oj)UOp%XO!e)VO~P#%}Oj)[Op)ZO~Oo)]O~OV)`OW)`OX)_Oj)`Op)`O&e(}O&f)OO&g)PO~OQ]OU$OOjQOkROlROwnOxXOzSO}VO!OmO!P$eO!R$eO!T$fO!X$eO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%x#XO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$POv&uX!x&uX#p&uX%X&uX%Z&uX%[&uX%^&uX%_&uX%`&uX%a&uX%b&uX%c&uX%d&uX%e&uX%f&uX%g&uX%h&uX%i&uX%j&uX%k&uX%l&uX%n&uX%o&uX%p&uX%q&uX%r&uX%s&uX%t&uX&|&uX'q&uX!d&uXr&uXt&uX#e&uX~OR#dOS#kOT#}Op%XO!Q#YO!YgO!ooO%v#YO%w#YO%z#[O!c&uX!g&uX#w&uX$`&uX$a&uX$b&uX$c&uX$d&uX~P#/zOQ]OU$OOjQOkROlROwnOxXOzSO}VO!OmO!P$eO!R$eO!T$fO!X$eO![^O!^`O!_aO!`bO!acO!ehO!iiO!llO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%x#XO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$POv&wX!x&wX#p&wX%X&wX%Z&wX%[&wX%^&wX%_&wX%`&wX%a&wX%b&wX%c&wX%d&wX%e&wX%f&wX%g&wX%h&wX%i&wX%j&wX%k&wX%l&wX%n&wX%o&wX%p&wX%q&wX%r&wX%s&wX%t&wX&|&wX'q&wX!d&wXr&wXt&wX#e&wX~OR#dOS#kOT#}Op%XO!Q#YO!YgO!ooO%v#YO%w#YO%z#[O!c&wX!g&wX#w&wX$`&wX$a&wX$b&wX$c&wX$d&wX~P#8OOQ]OR#dOS#kOT#}OU$OOjQOkROlROw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~Op)cO~P#@SOk)eO!e)fO#R!OO~Ok)hO!e)iO#R!OOv'RXw'RX!O'RX!Q'RX!['RX!c'RX!g'RX!o'RX!x'RX#T'RX#V'RX#X'RX#p'RX#w'RX$`'RX$a'RX$b'RX$c'RX$d'RX%X'RX%Z'RX%['RX%^'RX%_'RX%`'RX%a'RX%b'RX%c'RX%d'RX%e'RX%f'RX%g'RX%h'RX%i'RX%j'RX%k'RX%l'RX%n'RX%o'RX%p'RX%q'RX%r'RX%s'RX%t'RX%z'RX&|'RX'q'RX!d'RXr'RXt'RX#e'RX~Ok)kOl)kO!e)lO#R!OO#T!PO~Oj)nOw)oO!T$fO~OZ)qOa)rO~OZ)tO~P+vOQ]OR6kOS6wOT4}OU$OOjQOkROlROp5UOw%]OxXOzSO}VO!OmO!P$eO!Q5SO!R$eO!T$fO!X$eO!Y6gO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6hO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5SO%w5SO%x#XO%z6jO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~OQ)yOj)yOp)xO!T$fO!e(RO&l#yO~Ow)wO!O)vO~P$ dOQ]OR6kOS6wOT4}OU$OOjQOkROlROw%]OxXOzSO}VO!OmO!P$eO!Q5SO!R$eO!T$fO!X$eO!Y6gO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6hO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5SO%w5SO%x#XO%z6jO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~Op){O~P$!SOg*OO'|$oO~O`*ROa*PO~O^*SO~Ov*WOw*VO!O*YO'u*XO'v*TOQ(OX[(OX](OXj(OXk(OXl(OX!T(OX#R(OX's(OX't(OX'wnX(S(OX(a(OXZ(OX`(OX!x(OX_(OX~O'w*ZO~O(S*[O~P+vOv*WOw*VO!O*YO'u*XOQ'}X['}X]'}Xj'}Xk'}Xl'}X!T'}X#R'}X's'}X't'}X(S'}X(a'}XZ'}X`'}X!x'}X_'}X~O`*^O~P+vO^*`O~OP*aOp*aO~Oo$}Oo!Va~OP*cOp*cO~OP*gOp*gO~Oo%TOQ#maR#maS#maT#maU#maj#mak#mal#map#mav#maw#max#maz#ma}#ma!O#ma!P#ma!Q#ma!R#ma!T#ma!X#ma!Y#ma![#ma!^#ma!_#ma!`#ma!a#ma!e#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%v#ma%w#ma%x#ma%z#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&R#ma&U#ma&V#ma&W#ma&X#ma&Y#ma&`#ma&b#ma&c#ma&d#ma&i#ma&j#ma&l#ma&x#ma&z#ma'O#ma'P#ma'Q#ma'S#ma'T#ma'V#ma'W#ma'X#ma'x#ma(S#ma(a#ma*j#ma#p#ma'q#ma~Ot*lO~P`Ow&[Xw&rX!d#YXr#YX#e#YX~P7eOv$mOw$nO!O$lO!Q&^O![&_O!c'kO!g'kO!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO!d(^X~O!d*pO~Ow%]Ot(^P~PNfOw'yO!e'qO#e'sO~O`*sOb*qO~O^%`O~Or(^Xt(^X~P$2POr*vO~Ot(^X~P!%vOt*wO~O#p'nO'q'oO~P!3wOp*{O#p'nO'q'oO~P!3wOt*}O%T%jO%U%kO%V%lO~P`Ov$mOw$nO!O$lO%z&iO!c%ua!g%ua#p%ua#w%ua$`%ua$a%ua$b%ua$c%ua$d%ua%r%ua%s%ua%t%ua'q%ua!d%uar%uat%ua#e%ua~O!Q%ua![%ua!o%ua!x%ua#T%ua#V%ua#X%ua%X%ua%Z%ua%[%ua%^%ua%_%ua%`%ua%a%ua%b%ua%c%ua%d%ua%e%ua%f%ua%g%ua%h%ua%i%ua%j%ua%k%ua%l%ua%n%ua%o%ua%p%ua%q%ua&|%ua~P$6|OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e6oO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~Ow%]O%X+UO~PNfOv%]aw%]a!O%]a!Q%]a![%]a!c%]a!g%]a!o%]a!x%]a#T%]a#V%]a#X%]a#p%]a#w%]a$`%]a$a%]a$b%]a$c%]a$d%]a%X%]a%Z%]a%[%]a%^%]a%_%]a%`%]a%a%]a%j%]a%k%]a%l%]a%n%]a%o%]a%p%]a%q%]a%r%]a%s%]a%t%]a%z%]a&|%]a'q%]a!d%]ar%]at%]a#e%]a~O%b&OO%c%zO%d%{O%e%|O%f%}O%g%]a%h%]a%i%]a~P$?yO%g&SO%h&QO%i&RO%b%]a%c%]a%d%]a%e%]a%f%]a~P$?yO#e+hO~P#JWO(a+iO~P+vO`+kOa+jO~P+vO^+mO~O`+oOa+nO~P+vO^+qO~O!x+rO~P+vO`+uOa+tO~P+vO^+wO~O_+xO`+yOa+zO~P+vO^+}O~Oa,OO~O^,PO~OQ&[aR&[aS&[aT&[aU&[aj&[ak&[al&[ap&[av&^aw&[ax&[az&[a}&[a!O&[a!P&[a!Q&[a!R&[a!T&[a!X&[a!Y&[a![&[a!^&[a!_&[a!`&[a!a&[a!c&^a!e&[a!g&^a!i&[a!l&[a!o&[a!t&[a!v&[a!x&^a!z&[a!|&[a#O&[a#P&[a#R&[a#T&[a#V&[a#X&[a#[&[a#]&[a#^&[a#_&[a#a&[a#p&^a#w&^a$`&^a$a&^a$b&^a$c&^a$d&^a%X&^a%Z&^a%[&^a%^&^a%_&^a%`&^a%a&^a%b&^a%c&^a%d&^a%e&^a%f&^a%g&^a%h&^a%i&^a%j&^a%k&^a%l&^a%n&^a%o&^a%p&^a%q&^a%r&^a%s&^a%t&^a%v&[a%w&[a%x&[a%z&[a%|&[a%}&[a&O&[a&P&[a&Q&[a&R&[a&U&[a&V&[a&W&[a&X&[a&Y&[a&`&[a&b&[a&c&[a&d&[a&i&[a&j&[a&l&[a&x&[a&z&[a&|&^a'O&[a'P&[a'Q&[a'S&[a'T&[a'V&[a'W&[a'X&[a'q&^a'x&[a(S&[a(a&[a*j&[a!d&^ar&^at&^a#e&^a~Oo%TOw&^a!O&^a!Q&^a![&^a!o&^a#T&^a#V&^a#X&^a%z&^a~P$FOOQ]OjROkROlRO!X,WO!e,XO~O!d(nP~P$NrOp'vO~Oo%TOw#mX#n#mX#p#mX'q#mX~Ow'yO#n,_O#p'nO'q'oO~OQ#mXR#mXS#mXT#mXU#mXj#mXk#mXl#mXp#mXx#mXz#mX}#mX!O#mX!P#mX!Q#mX!R#mX!T#mX!X#mX!Y#mX![#mX!^#mX!_#mX!`#mX!a#mX!e#mX!i#mX!l#mX!o#mX!t#mX!v#mX!z#mX!|#mX#O#mX#P#mX#R#mX#T#mX#V#mX#X#mX#[#mX#]#mX#^#mX#_#mX#a#mX%v#mX%w#mX%x#mX%z#mX%|#mX%}#mX&O#mX&P#mX&Q#mX&R#mX&U#mX&V#mX&W#mX&X#mX&Y#mX&`#mX&b#mX&c#mX&d#mX&i#mX&j#mX&l#mX&x#mX&z#mX'O#mX'P#mX'Q#mX'S#mX'T#mX'V#mX'W#mX'X#mX'x#mX(S#mX(a#mX*j#mX!c#mX!g#mX~P% dO#n,cO#p'nO'q'oO~P$:cOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOw%]OxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~O!e6|O~P%'sO!c'kO!g'kO~OxYOzSO}VO![^O(SUO~Ok,hO!e%ZO!iiO~Ok,hO!e%ZO!iiO#p'nO'q'oO~P%-]Op,mOw%]O!o(tO~P%-]O!e,qO!iiO$W,tO#p)SP'q)SP~P%-]Oo%TO#p#mX'q#mX~O!c'iX!g'iX#p'iX'q'iX#w'iX$`'iX$a'iX$b'iX$c'iX$d'iX~P!-}O!c'kO!g'kO#p)Ua'q)Ua~O'r,zO's$iO't$jO~O#c,|O~PCROp-OO#i-PO~O!e(RO#e'sO~Ow'yO!e'qO#e'sO#p'nO'q'oO~Ot%qO%T%jO%U%kO%V%lO~P`Ow'yO#e-[O~O!e(RO#e-[O~Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%r&XO%s&YO%t&ZO%z&iO&|&jO~O!c)VX!g)VX#w)VX$`)VX$a)VX$b)VX$c)VX$d)VX#p)VX'q)VX~P%2SO!c'kO!g'kO#w)YX$`)YX$a)YX$b)YX$c)YX$d)YX#p)YX'q)YX~Oj-hO!e-fO#[!SO#]!TO#^!UO#_!VO$r-jO~O#p'nO'q'oOQ$saR$saS$saT$saU$sad$saj$sak$sal$sap$saw$sax$saz$sa}$sa!O$sa!P$sa!Q$sa!R$sa!T$sa!X$sa!Y$sa![$sa!^$sa!_$sa!`$sa!a$sa!e$sa!i$sa!l$sa!o$sa!t$sa!v$sa!z$sa!|$sa#O$sa#P$sa#R$sa#T$sa#V$sa#X$sa#[$sa#]$sa#^$sa#_$sa#a$sa#l$sa#p$sa#r$sa#s$sa#w$sa$Q$sa$Z$sa$_$sa$`$sa$a$sa$b$sa$c$sa$d$sa$w$sa$x$sa$y$sa$z$sa${$sa%Q$sa%R$sa%v$sa%w$sa%x$sa%z$sa%|$sa%}$sa&O$sa&P$sa&Q$sa&R$sa&U$sa&V$sa&W$sa&X$sa&Y$sa&`$sa&b$sa&c$sa&d$sa&i$sa&j$sa&l$sa&x$sa&z$sa'O$sa'P$sa'Q$sa'S$sa'T$sa'V$sa'W$sa'X$sa'p$sa'x$sa(S$sa(a$sa)i$sa*j$sat$sa%T$sa%U$sa%V$sa~O$n(aO~P%6fO#p'nO'q'oO~PCROj-hO~Ol-hO#[!SO#]!TO#^!UO#_!VO~Ow%WO~Of-sO~O!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%X%vO%Z%xO%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO&|&jO~P$6|Ov$mOw$nO!O$lO!Q%ya![%ya!c%ya!g%ya!o%ya!x%ya#T%ya#V%ya#X%ya#p%ya#w%ya$`%ya$a%ya$b%ya$c%ya$d%ya%X%ya%Z%ya%[%ya%^%ya%_%ya%`%ya%a%ya%b%ya%c%ya%d%ya%e%ya%f%ya%g%ya%h%ya%i%ya%j%ya%k%ya%l%ya%n%ya%o%ya%p%ya%q%ya%r%ya%s%ya%t%ya%z%ya&|%ya'q%ya!d%yar%yat%ya#e%ya~O!d-tO~O!c'kO!g'kO#p(wX#w(wX$`(wX$a(wX$b(wX$c(wX$d(wX'q(wX!d(wXr(wXt(wX#e(wX~P%2SOw-yO~Oj(uOw%]O!OmO!o(tO#a!YO~O%w6pO~P%E_OQ*eXR*eXS*eXT*eXU*eXj*eXk*eXl*eXp*eXx*eXz*eX}*eX!P*eX!Q*eX!R*eX!T*eX!X*eX!Y*eX![*eX!^*eX!_*eX!`*eX!a*eX!c*eX!e*eX!g*eX!i*eX!l*eX!o*eX!t*eX!v*eX!x*eX!z*eX!|*eX#O*eX#P*eX#R*eX#T*eX#V*eX#X*eX#[*eX#]*eX#^*eX#_*eX#a*eX#p*eX#w*eX$`*eX$a*eX$b*eX$c*eX$d*eX%X*eX%Z*eX%[*eX%^*eX%_*eX%`*eX%a*eX%b*eX%c*eX%d*eX%e*eX%f*eX%g*eX%h*eX%i*eX%j*eX%k*eX%l*eX%n*eX%o*eX%p*eX%q*eX%r*eX%s*eX%t*eX%v*eX%w*eX%x*eX%z*eX%|*eX%}*eX&O*eX&P*eX&Q*eX&R*eX&U*eX&V*eX&W*eX&X*eX&Y*eX&`*eX&b*eX&c*eX&d*eX&i*eX&j*eX&l*eX&x*eX&z*eX&|*eX'O*eX'P*eX'Q*eX'S*eX'T*eX'V*eX'W*eX'X*eX'q*eX'x*eX(S*eX(a*eX*j*eX!d*eXr*eXt*eX#e*eX~P(YOQ]OR#dOS#kOT#}OU$OOj5oOkROlROp({OwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&e(}O&f)OO&g)PO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO!d(^P~Ov(^P!c(^P!g(^P!x(^P#p(^P#w(^P$`(^P$a(^P$b(^P$c(^P$d(^P%X(^P%Z(^P%[(^P%^(^P%_(^P%`(^P%a(^P%b(^P%c(^P%d(^P%e(^P%f(^P%g(^P%h(^P%i(^P%j(^P%k(^P%l(^P%n(^P%o(^P%p(^P%q(^P%r(^P%s(^P%t(^P&|(^P'q(^Pr(^Pt(^P#e(^P~PCROQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO!c(^P!g(^P!x(^P#p(^P#w(^P$`(^P$a(^P$b(^P$c(^P$d(^P%X(^P%Z(^P%[(^P%^(^P%_(^P%`(^P%a(^P%b(^P%c(^P%d(^P%e(^P%f(^P%g(^P%h(^P%i(^P%j(^P%k(^P%l(^P%n(^P%o(^P%p(^P%q(^P%r(^P%s(^P%t(^P&|(^P'q(^P!d(^Pr(^Pt(^P#e(^P~Ov$mOw.SO!O.ROo(OX~P&'}OQ]OR#dOS#kOT#}OU$OOj.UOkROlROp%XOwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO!d(^P~Ow%]O!OmOv(^P~P&'}Oo%TOv#mXw#mX!O#mX!Q#mX![#mX!c#mX!e#mX!g#mX!o#mX!x#mX#T#mX#V#mX#X#mX#p#mX#w#mX$`#mX$a#mX$b#mX$c#mX$d#mX%X#mX%Z#mX%[#mX%^#mX%_#mX%`#mX%a#mX%b#mX%c#mX%d#mX%e#mX%f#mX%g#mX%h#mX%i#mX%j#mX%k#mX%l#mX%n#mX%o#mX%p#mX%q#mX%r#mX%s#mX%t#mX%z#mX&|#mX'q#mX!d#mXr#mXt#mX#e#mX~O!e(ROv&naw&na!O&na!Q&na![&na!c&na!g&na!o&na!x&na#T&na#V&na#X&na#p&na#w&na$`&na$a&na$b&na$c&na$d&na%X&na%Z&na%[&na%^&na%_&na%`&na%a&na%b&na%c&na%d&na%e&na%f&na%g&na%h&na%i&na%j&na%k&na%l&na%n&na%o&na%p&na%q&na%r&na%s&na%t&na%z&na&|&na'q&na!d&nar&nat&na#e&na~Op.YO~Ov$mOw$nO!O$lO%[%wO%c%zO%d%{O%e%|O%f%}O%h&QO%i&RO%k&UO%z&iO#V&sa#p&sa%X&sa%Z&sa%l&sa%n&sa%o&sa%p&sa%q&sa%r&sa%s&sa%t&sa&|&sa'q&sa!d&sar&sat&sa#e&sa~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O%b&OO%g&SO%j&`O!c&sa!g&sa#w&sa$`&sa$a&sa$b&sa$c&sa$d&sa~P&<tOX.[O~Oo%TOQ&[XR&[XS&[XT&[XU&[Xj&[Xj&oXk&[Xl&[Xp&[Xp&oXv&yaw&yax&[Xz&[X}&[X!O&ya!P&[X!Q&ya!R&[X!T&[X!X&[X!Y&[X![&ya!^&[X!_&[X!`&[X!a&[X!e&[X!i&[X!l&[X!o&ya!t&[X!v&[X!x&ya!z&[X!|&[X#O&[X#P&[X#R&[X#T&ya#V&ya#X&ya#[&[X#]&[X#^&[X#_&[X#a&[X#p&ya%X&ya%Z&ya%[&ya%^&ya%_&ya%`&ya%a&ya%b&ya%c&ya%d&ya%e&ya%f&ya%g&ya%h&ya%i&ya%j&ya%k&ya%l&ya%n&ya%o&ya%p&ya%q&ya%r&ya%s&ya%t&ya%v&[X%w&[X%x&[X%z&ya%|&[X%}&[X&O&[X&P&[X&Q&[X&R&[X&U&[X&V&[X&W&[X&X&[X&Y&[X&`&[X&b&[X&c&[X&d&[X&i&[X&j&[X&l&[X&x&[X&z&[X&|&ya'O&[X'P&[X'Q&[X'S&[X'T&[X'V&[X'W&[X'X&[X'q&ya'x&[X(S&[X(a&[X*j&[X!d&yar&yat&ya#e&ya~O!c&ya!g&ya#w&ya$`&ya$a&ya$b&ya$c&ya$d&ya~P&@`Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%q&fO%z&iO&|&jO~O!c&ya!g&ya#p&ya#w&ya$`&ya$a&ya$b&ya$c&ya$d&ya%X&ya%Z&ya%r&ya%s&ya%t&ya'q&ya!d&yar&yat&ya#e&ya~P&HmOk.^O#R!OO~Ok._O#R!OO~Ok.`Ol.`O#R!OO#T!PO~OZ.bO~OZ.cO~P+vOv$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#V&WO#X5`O%X5WO%Z5XO%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%g5]O%h&QO%i&RO%j5cO%k&UO%l&VO%n5fO%o5gO%p5hO%q5iO%r&XO%s&YO%t&ZO%z&iO&|6nO~Or.dO~P&MOOp.gO~P$!SO!e(ROv&kiw&ki!O&ki!Q&ki![&ki!c&ki!g&ki!o&ki!x&ki#T&ki#V&ki#X&ki#p&ki#w&ki$`&ki$a&ki$b&ki$c&ki$d&ki%X&ki%Z&ki%[&ki%^&ki%_&ki%`&ki%a&ki%b&ki%c&ki%d&ki%e&ki%f&ki%g&ki%h&ki%i&ki%j&ki%k&ki%l&ki%n&ki%o&ki%p&ki%q&ki%r&ki%s&ki%t&ki%z&ki&|&ki'q&ki!d&kir&kit&ki#e&ki~Oo.jO~Oo%TOt.kO!c5TOj&oXp&oXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROt.kO~P&MOOg.mO'|$oO^(Ra~O`.pOa*PO~Oo.rO~O'v*TO'wna~Oj.tOp.tOxYOzSO}VO(SUO~Ow.uO!O.vO~Ov.wOw.uO!O.vO~Oj.xOxYOzSO}VO!P.xO!Q.yO!R.xO(SUO~Oo.zO~O`.{O~P+vO%X%vO%Z%xO!c!bi!g!bi#p!bi#w!bi$`!bi$a!bi$b!bi$c!bi$d!bi%r!bi%s!bi%t!bi'q!bi!d!bir!bit!bi#e!bi~P&HmOt/PO~P`Ow%]O!c'aX!d'aX!g'aXr'aXt'aX#p'aX'q'aX~PNfO!c'kO!g'kO!d(^ar(^at(^a~O`/TOb*qO~Ot/UO~P&MOOt/XO~O%X%vO%Z%xO!c%Wi!g%Wi#p%Wi#w%Wi$`%Wi$a%Wi$b%Wi$c%Wi$d%Wi%r%Wi%s%Wi%t%Wi'q%Wi!d%Wir%Wit%Wi#e%Wi~P&HmO%X%vO%Z%xO!c%Yi!g%Yi#p%Yi#w%Yi$`%Yi$a%Yi$b%Yi$c%Yi$d%Yi%r%Yi%s%Yi%t%Yi'q%Yi!d%Yir%Yit%Yi#e%Yi~P&HmOv$mOw$nO!O$lO%^&[O%z&iO!Q%]i![%]i!c%]i!g%]i!o%]i!x%]i#T%]i#V%]i#X%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%[%]i%`%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!d%]ir%]it%]i#e%]i~O%_&[O~P'/oOv$mOw$nO!O$lO%[%wO%z&iO#V'ma#p'ma%X'ma%Z'ma%b'ma%c'ma%d'ma%e'ma%f'ma%g'ma%h'ma%i'ma%j'ma%k'ma%l'ma%n'ma%o'ma%p'ma%q'ma%r'ma%s'ma%t'ma&|'ma'q'ma!d'mar'mat'ma#e'ma~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O!c'ma!g'ma#w'ma$`'ma$a'ma$b'ma$c'ma$d'ma~P'3UOv$mOw$nO!O$lO%[%wO%c%zO%d%{O%e%|O%f%}O%z&iO#V'na#p'na%X'na%Z'na%g'na%h'na%i'na%j'na%k'na%l'na%n'na%o'na%p'na%q'na%r'na%s'na%t'na&|'na'q'na!d'nar'nat'na#e'na~O!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%^&[O%_&[O%`&^O%a&_O%b&OO!c'na!g'na#w'na$`'na$a'na$b'na$c'na$d'na~P'6kO%_%]i~P'/oOv$mOw$nO!O$lO!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%z&iO![%]i!c%]i!g%]i#V%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!d%]ir%]it%]i#e%]i~O!Q%]i!o%]i%`%]i~P':XO!Q&^O!o&^O%`&^O~P':XOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%z&iO!c%]i!g%]i#V%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!d%]ir%]it%]i#e%]i~O%g%]i%h%]i%i%]i%j%]i%k%]i~P'={O%g&SO%h&QO%i&RO%j&`O%k&UO~P'={Ov$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%z&iO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!d%]ir%]it%]i#e%]i~O#V%]i~P'AuO#V&WO~P'AuOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%z&iO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%X%]i%Z%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]i'q%]i!d%]ir%]it%]i#e%]i~O%o%]i~P'EcO%o&dO~P'EcOv$mOw$nO!O$lO!Q&^O![&_O!o&^O!x&]O#T&]O#V&WO#X&]O%[%wO%^&[O%_&[O%`&^O%a&_O%b&OO%c%zO%d%{O%e%|O%f%}O%g&SO%h&QO%i&RO%j&`O%k&UO%l&VO%n&cO%o&dO%p&eO%z&iO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%r%]i%s%]i%t%]i'q%]i!d%]ir%]it%]i#e%]i~O%X%]i%Z%]i%q%]i&|%]i~P'IPO%X%vO%Z%xO%q&fO&|&jO~P'IPO%X%vO%Z%xO%r&XO!c%]i!g%]i#p%]i#w%]i$`%]i$a%]i$b%]i$c%]i$d%]i%s%]i%t%]i'q%]i!d%]ir%]it%]i#e%]i~P&HmO#e/[O~P&MOO`/^O~O`/^O~P+vO`/^Oa/_O~P+vO`/aO~Oc/cO'y/bO~O`/aO~P+vO`/aOa/dO~P+vOc/gO'y/fO~O!x/hO~P+vO`/iO~Oc/kO'y/jO~O`/iO~P+vO`/iOa/lO~P+vO^/nO'|$oO~O_+xO`+yO~O`/rOa/qO~P+vO_+xO`+yO~P+vO_+xO`+yOa/tO~P+vOa/wO~Ot/xO~P&MOOt/yO~P&MOOt/zO~P&MOO!c#ma!g#ma!x#ma#w#ma$`#ma$a#ma$b#ma$c#ma$d#ma%X#ma%Z#ma%[#ma%^#ma%_#ma%`#ma%a#ma%b#ma%c#ma%d#ma%e#ma%f#ma%g#ma%h#ma%i#ma%j#ma%k#ma%l#ma%n#ma%o#ma%p#ma%q#ma%r#ma%s#ma%t#ma&|#ma!d#mar#mat#ma#e#ma~P$+{Ot/{O~P&MOOQ]OjROkROlRO!X/|O~O!c'kO!g'kO!d(nX~O!d0PO~Oo%TOw#ma#n#ma#p#ma'q#ma~Ow'yO#p'nO'q'oO~OQ#maR#maS#maT#maU#maj#mak#mal#map#max#maz#ma}#ma!O#ma!P#ma!Q#ma!R#ma!T#ma!X#ma!Y#ma![#ma!^#ma!_#ma!`#ma!a#ma!e#ma!i#ma!l#ma!o#ma!t#ma!v#ma!z#ma!|#ma#O#ma#P#ma#R#ma#T#ma#V#ma#X#ma#[#ma#]#ma#^#ma#_#ma#a#ma%v#ma%w#ma%x#ma%z#ma%|#ma%}#ma&O#ma&P#ma&Q#ma&R#ma&U#ma&V#ma&W#ma&X#ma&Y#ma&`#ma&b#ma&c#ma&d#ma&i#ma&j#ma&l#ma&x#ma&z#ma'O#ma'P#ma'Q#ma'S#ma'T#ma'V#ma'W#ma'X#ma'x#ma(S#ma(a#ma*j#ma!c#ma!g#ma~P('iO!c(xa!g(xa~P%2SOp'XO#t0YO~P%-]O!c'kO!g'kO#p)SX'q)SX~O!g0dO~O'r0fO's$iO't$jO~O!d0gO~O!d0hO~O!e(RO#e#daw#da#p#da'q#da~O!e0jO~Ow'yO#e-[O#p'nO'q'oO~Op-OO~O!c'kO!g'kO#w)Ya$`)Ya$a)Ya$b)Ya$c)Ya$d)Ya#p)Ya'q)Ya~O$g0qO$i0uOQ$eiR$eiS$eiT$eiU$eid$eij$eik$eil$eip$eiw$eix$eiz$ei}$ei!O$ei!P$ei!Q$ei!R$ei!T$ei!X$ei!Y$ei![$ei!^$ei!_$ei!`$ei!a$ei!e$ei!i$ei!l$ei!o$ei!t$ei!v$ei!z$ei!|$ei#O$ei#P$ei#R$ei#T$ei#V$ei#X$ei#[$ei#]$ei#^$ei#_$ei#a$ei#l$ei#p$ei#r$ei#s$ei#w$ei$Q$ei$Z$ei$_$ei$`$ei$a$ei$b$ei$c$ei$d$ei$w$ei$x$ei$y$ei$z$ei${$ei%Q$ei%R$ei%v$ei%w$ei%x$ei%z$ei%|$ei%}$ei&O$ei&P$ei&Q$ei&R$ei&U$ei&V$ei&W$ei&X$ei&Y$ei&`$ei&b$ei&c$ei&d$ei&i$ei&j$ei&l$ei&x$ei&z$ei'O$ei'P$ei'Q$ei'S$ei'T$ei'V$ei'W$ei'X$ei'p$ei'x$ei(S$ei(a$ei)i$ei*j$eit$ei%T$ei%U$ei%V$ei~O$g0qO$i0uOQ$jiR$jiS$jiT$jiU$jid$jij$jik$jil$jip$jiw$jix$jiz$ji}$ji!O$ji!P$ji!Q$ji!R$ji!T$ji!X$ji!Y$ji![$ji!^$ji!_$ji!`$ji!a$ji!e$ji!i$ji!l$ji!o$ji!t$ji!v$ji!z$ji!|$ji#O$ji#P$ji#R$ji#T$ji#V$ji#X$ji#[$ji#]$ji#^$ji#_$ji#a$ji#l$ji#p$ji#r$ji#s$ji#w$ji$Q$ji$Z$ji$_$ji$`$ji$a$ji$b$ji$c$ji$d$ji$w$ji$x$ji$y$ji$z$ji${$ji%Q$ji%R$ji%v$ji%w$ji%x$ji%z$ji%|$ji%}$ji&O$ji&P$ji&Q$ji&R$ji&U$ji&V$ji&W$ji&X$ji&Y$ji&`$ji&b$ji&c$ji&d$ji&i$ji&j$ji&l$ji&x$ji&z$ji'O$ji'P$ji'Q$ji'S$ji'T$ji'V$ji'W$ji'X$ji'p$ji'x$ji(S$ji(a$ji)i$ji*j$jit$ji%T$ji%U$ji%V$ji~O$n(aOQ$kiR$kiS$kiT$kiU$kid$kij$kik$kil$kip$kiw$kix$kiz$ki}$ki!O$ki!P$ki!Q$ki!R$ki!T$ki!X$ki!Y$ki![$ki!^$ki!_$ki!`$ki!a$ki!e$ki!i$ki!l$ki!o$ki!t$ki!v$ki!z$ki!|$ki#O$ki#P$ki#R$ki#T$ki#V$ki#X$ki#[$ki#]$ki#^$ki#_$ki#a$ki#l$ki#p$ki#r$ki#s$ki#w$ki$Q$ki$Z$ki$_$ki$`$ki$a$ki$b$ki$c$ki$d$ki$w$ki$x$ki$y$ki$z$ki${$ki%Q$ki%R$ki%v$ki%w$ki%x$ki%z$ki%|$ki%}$ki&O$ki&P$ki&Q$ki&R$ki&U$ki&V$ki&W$ki&X$ki&Y$ki&`$ki&b$ki&c$ki&d$ki&i$ki&j$ki&l$ki&x$ki&z$ki'O$ki'P$ki'Q$ki'S$ki'T$ki'V$ki'W$ki'X$ki'p$ki'x$ki(S$ki(a$ki)i$ki*j$kit$ki%T$ki%U$ki%V$ki~Oj1RO~Ol1RO#[!SO#]!TO#^!UO#_!VO~O#p'nO'q'oOQ$siR$siS$siT$siU$sid$sij$sik$sil$sip$siw$six$siz$si}$si!O$si!P$si!Q$si!R$si!T$si!X$si!Y$si![$si!^$si!_$si!`$si!a$si!e$si!i$si!l$si!o$si!t$si!v$si!z$si!|$si#O$si#P$si#R$si#T$si#V$si#X$si#[$si#]$si#^$si#_$si#a$si#l$si#p$si#r$si#s$si#w$si$Q$si$Z$si$_$si$`$si$a$si$b$si$c$si$d$si$w$si$x$si$y$si$z$si${$si%Q$si%R$si%v$si%w$si%x$si%z$si%|$si%}$si&O$si&P$si&Q$si&R$si&U$si&V$si&W$si&X$si&Y$si&`$si&b$si&c$si&d$si&i$si&j$si&l$si&x$si&z$si'O$si'P$si'Q$si'S$si'T$si'V$si'W$si'X$si'p$si'x$si(S$si(a$si)i$si*j$sit$si%T$si%U$si%V$si~O$n(aOQ$oiR$oiS$oiT$oiU$oid$oij$oik$oil$oip$oiw$oix$oiz$oi}$oi!O$oi!P$oi!Q$oi!R$oi!T$oi!X$oi!Y$oi![$oi!^$oi!_$oi!`$oi!a$oi!e$oi!i$oi!l$oi!o$oi!t$oi!v$oi!z$oi!|$oi#O$oi#P$oi#R$oi#T$oi#V$oi#X$oi#[$oi#]$oi#^$oi#_$oi#a$oi#l$oi#p$oi#r$oi#s$oi#w$oi$Q$oi$Z$oi$_$oi$`$oi$a$oi$b$oi$c$oi$d$oi$w$oi$x$oi$y$oi$z$oi${$oi%Q$oi%R$oi%v$oi%w$oi%x$oi%z$oi%|$oi%}$oi&O$oi&P$oi&Q$oi&R$oi&U$oi&V$oi&W$oi&X$oi&Y$oi&`$oi&b$oi&c$oi&d$oi&i$oi&j$oi&l$oi&x$oi&z$oi'O$oi'P$oi'Q$oi'S$oi'T$oi'V$oi'W$oi'X$oi'p$oi'x$oi(S$oi(a$oi)i$oi*j$oit$oi%T$oi%U$oi%V$oi~O#p'nO'q'oO~P$2PO$n(aOQ$qiR$qiS$qiT$qiU$qid$qij$qik$qil$qip$qiw$qix$qiz$qi}$qi!O$qi!P$qi!Q$qi!R$qi!T$qi!X$qi!Y$qi![$qi!^$qi!_$qi!`$qi!a$qi!e$qi!i$qi!l$qi!o$qi!t$qi!v$qi!z$qi!|$qi#O$qi#P$qi#R$qi#T$qi#V$qi#X$qi#[$qi#]$qi#^$qi#_$qi#a$qi#l$qi#p$qi#r$qi#s$qi#w$qi$Q$qi$Z$qi$_$qi$`$qi$a$qi$b$qi$c$qi$d$qi$w$qi$x$qi$y$qi$z$qi${$qi%Q$qi%R$qi%v$qi%w$qi%x$qi%z$qi%|$qi%}$qi&O$qi&P$qi&Q$qi&R$qi&U$qi&V$qi&W$qi&X$qi&Y$qi&`$qi&b$qi&c$qi&d$qi&i$qi&j$qi&l$qi&x$qi&z$qi'O$qi'P$qi'Q$qi'S$qi'T$qi'V$qi'W$qi'X$qi'p$qi'x$qi(S$qi(a$qi)i$qi*j$qit$qi%T$qi%U$qi%V$qi~Ol1RO~Ow%]Ov'aX!c'aX!g'aX!x'aX#p'aX#w'aX$`'aX$a'aX$b'aX$c'aX$d'aX%X'aX%Z'aX%['aX%^'aX%_'aX%`'aX%a'aX%b'aX%c'aX%d'aX%e'aX%f'aX%g'aX%h'aX%i'aX%j'aX%k'aX%l'aX%n'aX%o'aX%p'aX%q'aX%r'aX%s'aX%t'aX&|'aX'q'aX!d'aXr'aXt'aX#e'aX~PNfO!c'kO!g'kO#p(wa'q(wa!d(wa~Ov(waw(wa!O(wa!Q(wa![(wa!o(wa!x(wa#T(wa#V(wa#X(wa#w(wa$`(wa$a(wa$b(wa$c(wa$d(wa%X(wa%Z(wa%[(wa%^(wa%_(wa%`(wa%a(wa%b(wa%c(wa%d(wa%e(wa%f(wa%g(wa%h(wa%i(wa%j(wa%k(wa%l(wa%n(wa%o(wa%p(wa%q(wa%r(wa%s(wa%t(wa%z(wa&|(war(wat(wa#e(wa~P)0vO!c'kO!g'kOv)UXw)UX!O)UX!Q)UX![)UX!o)UX!x)UX#T)UX#V)UX#X)UX#p)UX#w)UX$`)UX$a)UX$b)UX$c)UX$d)UX%X)UX%Z)UX%[)UX%^)UX%_)UX%`)UX%a)UX%b)UX%c)UX%d)UX%e)UX%f)UX%g)UX%h)UX%i)UX%j)UX%k)UX%l)UX%n)UX%o)UX%p)UX%q)UX%r)UX%s)UX%t)UX%z)UX&|)UX'q)UX!d)UXr)UXt)UX#e)UX~O!c'kO!d1^O!g'kO~Ov$mOw$nO!O$lO%z&iO!c*]a!g*]a!d*]a~O!Q*]a![*]a!o*]a!x*]a#T*]a#V*]a#X*]a#p*]a#w*]a$`*]a$a*]a$b*]a$c*]a$d*]a%X*]a%Z*]a%[*]a%^*]a%_*]a%`*]a%a*]a%b*]a%c*]a%d*]a%e*]a%f*]a%g*]a%h*]a%i*]a%j*]a%k*]a%l*]a%n*]a%o*]a%p*]a%q*]a%r*]a%s*]a%t*]a&|*]a'q*]ar*]at*]a#e*]a~P)7yOv(^aw(^a!O(^a!Q(^a![(^a!o(^a!x(^a#T(^a#V(^a#X(^a#p(^a#w(^a$`(^a$a(^a$b(^a$c(^a$d(^a%X(^a%Z(^a%[(^a%^(^a%_(^a%`(^a%a(^a%b(^a%c(^a%d(^a%e(^a%f(^a%g(^a%h(^a%i(^a%j(^a%k(^a%l(^a%n(^a%o(^a%p(^a%q(^a%r(^a%s(^a%t(^a%z(^a&|(^a'q(^a#e(^a~P',YO!d1`O~Op5uOt(^P~P#@SOQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOv$mOw.SOxXOzSO}VO!O.RO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$POo(OX!c(OX!d(^P!g(OX~O!x(OX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX&|(OX~P)>sO!d1eO~Oj1fOp)ZO~O!d1iO~O!d1jO~Ot1kO~P&MOO!c'kO!g'kOr*[Xv*[Xw*[X!O*[X!Q*[X![*[X!o*[X!x*[X#T*[X#V*[X#X*[X%X*[X%Z*[X%[*[X%^*[X%_*[X%`*[X%a*[X%b*[X%c*[X%d*[X%e*[X%f*[X%g*[X%h*[X%i*[X%j*[X%k*[X%l*[X%n*[X%o*[X%p*[X%q*[X%r*[X%s*[X%t*[X%z*[X&|*[Xt*[X#e*[X#p*[X'q*[X!d*[X~Or1lO~P&MOOo%TOt1mO!c5TOj&oXp&oXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROt1mO~P&MOOp)xO~Og1oO'|$oO~Og.mO'|$oO^(Ri~O`1qOa*PO~OP1rOp1rO~Ot1sO~Oj1tOp1tOxYOzSO}VO(SUO~Oj1uOxYOzSO}VO!P1uO!Q1vO!R1uO(SUO~Ow1wO!O1xO~Or1yO~O!P1uO~OP1zOp1zO~O`1|O~P+vO!c'aa!d'aa!g'aar'aat'aa#p'aa#w'aa$`'aa$a'aa$b'aa$c'aa$d'aa'q'aa#e'aa~P%2SOv!niv!nqw!niw!nq!O!ni!O!nq!Q!ni!Q!nq![!ni![!nq!c!ni!c!nq!g!ni!g!nq!o!ni!o!nq!x!ni!x!nq#T!ni#T!nq#V!ni#V!nq#X!ni#X!nq#p!ni#p!nq#w!ni#w!nq$`!ni$`!nq$a!ni$a!nq$b!ni$b!nq$c!ni$c!nq$d!ni$d!nq%X!ni%X!nq%Z!ni%Z!nq%[!ni%[!nq%^!ni%^!nq%_!ni%_!nq%`!ni%`!nq%a!ni%a!nq%b!ni%b!nq%c!ni%c!nq%d!ni%d!nq%e!ni%e!nq%f!ni%f!nq%g!ni%g!nq%h!ni%h!nq%i!ni%i!nq%j!ni%j!nq%k!ni%k!nq%l!ni%l!nq%n!ni%n!nq%o!ni%o!nq%p!ni%p!nq%q!ni%q!nq%r!ni%r!nq%s!ni%s!nq%t!ni%t!nq%z!ni%z!nq&|!ni&|!nq'q!ni'q!nq!d!ni!d!nqr!nir!nqt!nit!nq#e!ni#e!nq~O%X%vO%Z%xO!c%Yq!g%Yq#p%Yq#w%Yq$`%Yq$a%Yq$b%Yq$c%Yq$d%Yq%r%Yq%s%Yq%t%Yq'q%Yq!d%Yqr%Yqt%Yq#e%Yq~P&HmO!c&{q!g&{q#p&{q#w&{q$`&{q$a&{q$b&{q$c&{q$d&{q%X&{q%Z&{q%r&{q%s&{q%t&{q'q&{q!d&{qr&{qt&{q#e&{q~P&HmO`2QO~O`2QO~P+vOc2SO'y2RO~O`2TO~O`2TO~P+vO'y2UO~Oc2VO'y2UO~Oc2XO'y2WO~O`2YO~O`2YO~P+vO^2ZO~O`2]Oa2[O~P+vO`2]O~Oc2`O'y2_O~O`2]O~P+vOa2bO~O!d2dO~O!c'cX!d'cX!g'cX~P$NrO!c'kO!g'kO!d(na~O!c'kO!g'kO#n2pO#p'nO'q'oO~P$:cO!d2rO~O!e,qO!c'hX!g'hX#p'hX'q'hX~P%-]O!c'kO!g'kO#p)Sa'q)Sa~O!e,qO!iiO#p)SP'q)SP~P%-]O!d,{O#c,|O~O$g0qO$i0uOQ$eqR$eqS$eqT$eqU$eqd$eqj$eqk$eql$eqp$eqw$eqx$eqz$eq}$eq!O$eq!P$eq!Q$eq!R$eq!T$eq!X$eq!Y$eq![$eq!^$eq!_$eq!`$eq!a$eq!e$eq!i$eq!l$eq!o$eq!t$eq!v$eq!z$eq!|$eq#O$eq#P$eq#R$eq#T$eq#V$eq#X$eq#[$eq#]$eq#^$eq#_$eq#a$eq#l$eq#p$eq#r$eq#s$eq#w$eq$Q$eq$Z$eq$_$eq$`$eq$a$eq$b$eq$c$eq$d$eq$w$eq$x$eq$y$eq$z$eq${$eq%Q$eq%R$eq%v$eq%w$eq%x$eq%z$eq%|$eq%}$eq&O$eq&P$eq&Q$eq&R$eq&U$eq&V$eq&W$eq&X$eq&Y$eq&`$eq&b$eq&c$eq&d$eq&i$eq&j$eq&l$eq&x$eq&z$eq'O$eq'P$eq'Q$eq'S$eq'T$eq'V$eq'W$eq'X$eq'p$eq'x$eq(S$eq(a$eq)i$eq*j$eqt$eq%T$eq%U$eq%V$eq~O$g0qO$i0uOQ$jqR$jqS$jqT$jqU$jqd$jqj$jqk$jql$jqp$jqw$jqx$jqz$jq}$jq!O$jq!P$jq!Q$jq!R$jq!T$jq!X$jq!Y$jq![$jq!^$jq!_$jq!`$jq!a$jq!e$jq!i$jq!l$jq!o$jq!t$jq!v$jq!z$jq!|$jq#O$jq#P$jq#R$jq#T$jq#V$jq#X$jq#[$jq#]$jq#^$jq#_$jq#a$jq#l$jq#p$jq#r$jq#s$jq#w$jq$Q$jq$Z$jq$_$jq$`$jq$a$jq$b$jq$c$jq$d$jq$w$jq$x$jq$y$jq$z$jq${$jq%Q$jq%R$jq%v$jq%w$jq%x$jq%z$jq%|$jq%}$jq&O$jq&P$jq&Q$jq&R$jq&U$jq&V$jq&W$jq&X$jq&Y$jq&`$jq&b$jq&c$jq&d$jq&i$jq&j$jq&l$jq&x$jq&z$jq'O$jq'P$jq'Q$jq'S$jq'T$jq'V$jq'W$jq'X$jq'p$jq'x$jq(S$jq(a$jq)i$jq*j$jqt$jq%T$jq%U$jq%V$jq~O$n(aOQ$kqR$kqS$kqT$kqU$kqd$kqj$kqk$kql$kqp$kqw$kqx$kqz$kq}$kq!O$kq!P$kq!Q$kq!R$kq!T$kq!X$kq!Y$kq![$kq!^$kq!_$kq!`$kq!a$kq!e$kq!i$kq!l$kq!o$kq!t$kq!v$kq!z$kq!|$kq#O$kq#P$kq#R$kq#T$kq#V$kq#X$kq#[$kq#]$kq#^$kq#_$kq#a$kq#l$kq#p$kq#r$kq#s$kq#w$kq$Q$kq$Z$kq$_$kq$`$kq$a$kq$b$kq$c$kq$d$kq$w$kq$x$kq$y$kq$z$kq${$kq%Q$kq%R$kq%v$kq%w$kq%x$kq%z$kq%|$kq%}$kq&O$kq&P$kq&Q$kq&R$kq&U$kq&V$kq&W$kq&X$kq&Y$kq&`$kq&b$kq&c$kq&d$kq&i$kq&j$kq&l$kq&x$kq&z$kq'O$kq'P$kq'Q$kq'S$kq'T$kq'V$kq'W$kq'X$kq'p$kq'x$kq(S$kq(a$kq)i$kq*j$kqt$kq%T$kq%U$kq%V$kq~O$n(aOQ$oqR$oqS$oqT$oqU$oqd$oqj$oqk$oql$oqp$oqw$oqx$oqz$oq}$oq!O$oq!P$oq!Q$oq!R$oq!T$oq!X$oq!Y$oq![$oq!^$oq!_$oq!`$oq!a$oq!e$oq!i$oq!l$oq!o$oq!t$oq!v$oq!z$oq!|$oq#O$oq#P$oq#R$oq#T$oq#V$oq#X$oq#[$oq#]$oq#^$oq#_$oq#a$oq#l$oq#p$oq#r$oq#s$oq#w$oq$Q$oq$Z$oq$_$oq$`$oq$a$oq$b$oq$c$oq$d$oq$w$oq$x$oq$y$oq$z$oq${$oq%Q$oq%R$oq%v$oq%w$oq%x$oq%z$oq%|$oq%}$oq&O$oq&P$oq&Q$oq&R$oq&U$oq&V$oq&W$oq&X$oq&Y$oq&`$oq&b$oq&c$oq&d$oq&i$oq&j$oq&l$oq&x$oq&z$oq'O$oq'P$oq'Q$oq'S$oq'T$oq'V$oq'W$oq'X$oq'p$oq'x$oq(S$oq(a$oq)i$oq*j$oqt$oq%T$oq%U$oq%V$oq~O$n(aOQ$qqR$qqS$qqT$qqU$qqd$qqj$qqk$qql$qqp$qqw$qqx$qqz$qq}$qq!O$qq!P$qq!Q$qq!R$qq!T$qq!X$qq!Y$qq![$qq!^$qq!_$qq!`$qq!a$qq!e$qq!i$qq!l$qq!o$qq!t$qq!v$qq!z$qq!|$qq#O$qq#P$qq#R$qq#T$qq#V$qq#X$qq#[$qq#]$qq#^$qq#_$qq#a$qq#l$qq#p$qq#r$qq#s$qq#w$qq$Q$qq$Z$qq$_$qq$`$qq$a$qq$b$qq$c$qq$d$qq$w$qq$x$qq$y$qq$z$qq${$qq%Q$qq%R$qq%v$qq%w$qq%x$qq%z$qq%|$qq%}$qq&O$qq&P$qq&Q$qq&R$qq&U$qq&V$qq&W$qq&X$qq&Y$qq&`$qq&b$qq&c$qq&d$qq&i$qq&j$qq&l$qq&x$qq&z$qq'O$qq'P$qq'Q$qq'S$qq'T$qq'V$qq'W$qq'X$qq'p$qq'x$qq(S$qq(a$qq)i$qq*j$qqt$qq%T$qq%U$qq%V$qq~Ol3UO~O!d3WO~Ov'iX!c'iX!g'iX!x'iX#p'iX#w'iX$`'iX$a'iX$b'iX$c'iX$d'iX%X'iX%Z'iX%['iX%^'iX%_'iX%`'iX%a'iX%b'iX%c'iX%d'iX%e'iX%f'iX%g'iX%h'iX%i'iX%j'iX%k'iX%l'iX%n'iX%o'iX%p'iX%q'iX%r'iX%s'iX%t'iX&|'iX'q'iX!d'iXr'iXt'iX#e'iX~P!-}O!c'kO!g'kOv)Uaw)Ua!O)Ua!Q)Ua![)Ua!o)Ua!x)Ua#T)Ua#V)Ua#X)Ua#p)Ua#w)Ua$`)Ua$a)Ua$b)Ua$c)Ua$d)Ua%X)Ua%Z)Ua%[)Ua%^)Ua%_)Ua%`)Ua%a)Ua%b)Ua%c)Ua%d)Ua%e)Ua%f)Ua%g)Ua%h)Ua%i)Ua%j)Ua%k)Ua%l)Ua%n)Ua%o)Ua%p)Ua%q)Ua%r)Ua%s)Ua%t)Ua%z)Ua&|)Ua'q)Ua!d)Uar)Uat)Ua#e)Ua~Ot3XO~Ov$mOw$nO!O$lO!Q*[i![*[i!c*[i!g*[i!o*[i!x*[i#T*[i#V*[i#X*[i#p*[i#w*[i$`*[i$a*[i$b*[i$c*[i$d*[i%X*[i%Z*[i%[*[i%^*[i%_*[i%`*[i%a*[i%b*[i%c*[i%d*[i%e*[i%f*[i%g*[i%h*[i%i*[i%j*[i%k*[i%l*[i%n*[i%o*[i%p*[i%q*[i%r*[i%s*[i%t*[i%z*[i&|*[i'q*[i!d*[ir*[it*[i#e*[i~O!d3ZO~O!c'kO!g'kOr(^X~P%2SO!c'kO!g'kOt(^X~P%2SO!d3[O~O!e(ROv&nqw&nq!O&nq!Q&nq![&nq!c&nq!g&nq!o&nq!x&nq#T&nq#V&nq#X&nq#p&nq#w&nq$`&nq$a&nq$b&nq$c&nq$d&nq%X&nq%Z&nq%[&nq%^&nq%_&nq%`&nq%a&nq%b&nq%c&nq%d&nq%e&nq%f&nq%g&nq%h&nq%i&nq%j&nq%k&nq%l&nq%n&nq%o&nq%p&nq%q&nq%r&nq%s&nq%t&nq%z&nq&|&nq'q&nq!d&nqr&nqt&nq#e&nq~O!e(ROv&kyw&ky!O&ky!Q&ky![&ky!c&ky!g&ky!o&ky!x&ky#T&ky#V&ky#X&ky#p&ky#w&ky$`&ky$a&ky$b&ky$c&ky$d&ky%X&ky%Z&ky%[&ky%^&ky%_&ky%`&ky%a&ky%b&ky%c&ky%d&ky%e&ky%f&ky%g&ky%h&ky%i&ky%j&ky%k&ky%l&ky%n&ky%o&ky%p&ky%q&ky%r&ky%s&ky%t&ky%z&ky&|&ky'q&ky!d&kyr&kyt&ky#e&ky~Ot3bO~Or3cO~O!P3dO~Oj3eOp3eOxYOzSO}VO(SUO~Oj3dOxYOzSO}VO!P3dO!Q3fO!R3dO(SUO~Ov!fiw!fi!O!fi!Q!fi![!fi!o!fi!x!fi#T!fi#V!fi#X!fi%X!fi%Z!fi%[!fi%^!fi%_!fi%`!fi%a!fi%b!fi%c!fi%d!fi%e!fi%f!fi%g!fi%h!fi%i!fi%j!fi%k!fi%l!fi%n!fi%o!fi%p!fi%q!fi%r!fi%s!fi%t!fi%z!fi&|!fi~O!c!fi!g!fi#p#gi'q#gi!d#gi~P+8kO!c&{y!g&{y#p&{y#w&{y$`&{y$a&{y$b&{y$c&{y$d&{y%X&{y%Z&{y%r&{y%s&{y%t&{y'q&{y!d&{yr&{yt&{y#e&{y~P&HmO'y3gO~Oc3hO'y3gO~O'y3iO~O'y3jO~Oc3kO'y3jO~O`3lO~Oc3nO'y3mO~O`3lO~P+vO`3lOa3oO~P+vO`3qO~Oa3rO~O!c'kO!g'kO#p'nO'q'oO~P$:cO#p'nO'q'oO~P&MOO!d4OO~O$n(aOQ$qyR$qyS$qyT$qyU$qyd$qyj$qyk$qyl$qyp$qyw$qyx$qyz$qy}$qy!O$qy!P$qy!Q$qy!R$qy!T$qy!X$qy!Y$qy![$qy!^$qy!_$qy!`$qy!a$qy!e$qy!i$qy!l$qy!o$qy!t$qy!v$qy!z$qy!|$qy#O$qy#P$qy#R$qy#T$qy#V$qy#X$qy#[$qy#]$qy#^$qy#_$qy#a$qy#l$qy#p$qy#r$qy#s$qy#w$qy$Q$qy$Z$qy$_$qy$`$qy$a$qy$b$qy$c$qy$d$qy$w$qy$x$qy$y$qy$z$qy${$qy%Q$qy%R$qy%v$qy%w$qy%x$qy%z$qy%|$qy%}$qy&O$qy&P$qy&Q$qy&R$qy&U$qy&V$qy&W$qy&X$qy&Y$qy&`$qy&b$qy&c$qy&d$qy&i$qy&j$qy&l$qy&x$qy&z$qy'O$qy'P$qy'Q$qy'S$qy'T$qy'V$qy'W$qy'X$qy'p$qy'x$qy(S$qy(a$qy)i$qy*j$qyt$qy%T$qy%U$qy%V$qy~O!d4UO~P&MOO!d4VO~Or*aiv*aiw*ai!O*ai!Q*ai![*ai!c!fi!g!fi!o*ai!x*ai#T*ai#V*ai#X*ai%X*ai%Z*ai%[*ai%^*ai%_*ai%`*ai%a*ai%b*ai%c*ai%d*ai%e*ai%f*ai%g*ai%h*ai%i*ai%j*ai%k*ai%l*ai%n*ai%o*ai%p*ai%q*ai%r*ai%s*ai%t*ai%z*ai&|*ait*ai#e*ai#p*ai'q*ai!d*ai~Or*hiv*hiw*hi!O*hi!Q*hi![*hi!c!fi!g!fi!o*hi!x*hi#T*hi#V*hi#X*hi%X*hi%Z*hi%[*hi%^*hi%_*hi%`*hi%a*hi%b*hi%c*hi%d*hi%e*hi%f*hi%g*hi%h*hi%i*hi%j*hi%k*hi%l*hi%n*hi%o*hi%p*hi%q*hi%r*hi%s*hi%t*hi%z*hi&|*hit*hi#e*hi#p*hi'q*hi!d*hi~Or4WO~Ot4XO~O!P4YO~O'y4ZO~O'y4[O~Oc4^O'y4]O~O`4_O~O`4_O~P+vOc4aO'y4`O~O`4bO~O$n(aOQ$q!RR$q!RS$q!RT$q!RU$q!Rd$q!Rj$q!Rk$q!Rl$q!Rp$q!Rw$q!Rx$q!Rz$q!R}$q!R!O$q!R!P$q!R!Q$q!R!R$q!R!T$q!R!X$q!R!Y$q!R![$q!R!^$q!R!_$q!R!`$q!R!a$q!R!e$q!R!i$q!R!l$q!R!o$q!R!t$q!R!v$q!R!z$q!R!|$q!R#O$q!R#P$q!R#R$q!R#T$q!R#V$q!R#X$q!R#[$q!R#]$q!R#^$q!R#_$q!R#a$q!R#l$q!R#p$q!R#r$q!R#s$q!R#w$q!R$Q$q!R$Z$q!R$_$q!R$`$q!R$a$q!R$b$q!R$c$q!R$d$q!R$w$q!R$x$q!R$y$q!R$z$q!R${$q!R%Q$q!R%R$q!R%v$q!R%w$q!R%x$q!R%z$q!R%|$q!R%}$q!R&O$q!R&P$q!R&Q$q!R&R$q!R&U$q!R&V$q!R&W$q!R&X$q!R&Y$q!R&`$q!R&b$q!R&c$q!R&d$q!R&i$q!R&j$q!R&l$q!R&x$q!R&z$q!R'O$q!R'P$q!R'Q$q!R'S$q!R'T$q!R'V$q!R'W$q!R'X$q!R'p$q!R'x$q!R(S$q!R(a$q!R)i$q!R*j$q!Rt$q!R%T$q!R%U$q!R%V$q!R~Or4lO~O'y4mO~Oc4nO'y4mO~O'y4oO~Oc4pO'y4oO~O$n(aOQ$q!ZR$q!ZS$q!ZT$q!ZU$q!Zd$q!Zj$q!Zk$q!Zl$q!Zp$q!Zw$q!Zx$q!Zz$q!Z}$q!Z!O$q!Z!P$q!Z!Q$q!Z!R$q!Z!T$q!Z!X$q!Z!Y$q!Z![$q!Z!^$q!Z!_$q!Z!`$q!Z!a$q!Z!e$q!Z!i$q!Z!l$q!Z!o$q!Z!t$q!Z!v$q!Z!z$q!Z!|$q!Z#O$q!Z#P$q!Z#R$q!Z#T$q!Z#V$q!Z#X$q!Z#[$q!Z#]$q!Z#^$q!Z#_$q!Z#a$q!Z#l$q!Z#p$q!Z#r$q!Z#s$q!Z#w$q!Z$Q$q!Z$Z$q!Z$_$q!Z$`$q!Z$a$q!Z$b$q!Z$c$q!Z$d$q!Z$w$q!Z$x$q!Z$y$q!Z$z$q!Z${$q!Z%Q$q!Z%R$q!Z%v$q!Z%w$q!Z%x$q!Z%z$q!Z%|$q!Z%}$q!Z&O$q!Z&P$q!Z&Q$q!Z&R$q!Z&U$q!Z&V$q!Z&W$q!Z&X$q!Z&Y$q!Z&`$q!Z&b$q!Z&c$q!Z&d$q!Z&i$q!Z&j$q!Z&l$q!Z&x$q!Z&z$q!Z'O$q!Z'P$q!Z'Q$q!Z'S$q!Z'T$q!Z'V$q!Z'W$q!Z'X$q!Z'p$q!Z'x$q!Z(S$q!Z(a$q!Z)i$q!Z*j$q!Zt$q!Z%T$q!Z%U$q!Z%V$q!Z~O!d4uO~P&MOO'y4vO~O'y4wO~O!d4xO~P&MOOj&xOw&yO!T5RO~OR6kOS6wOT4}Op5UO!Q5SO!Y6gO!o6hO%v5SO%w5SO%z6jO~P#/zOR6kOS6wOT4}Op5UO!Q5SO!Y6gO!o6hO%v5SO%w5SO%z6jO~P#8OOp5sO~P$!SOj)nOw)oO!T5RO~Oo%TO!c5TOj&oXp&oXr#YXv#mXw&rX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YXt#YX#e#YX#p#YX'q#YX!d#YX~P!NRO#p(^X#w(^X$`(^X$a(^X$b(^X$c(^X$d(^X'q(^Xr(^Xt(^X#e(^X~P$2PO%X5zO~P#JWOr%]av%]aw%]a!O%]a!Q%]a![%]a!o%]a!x%]a#T%]a#V%]a#X%]a%X%]a%Z%]a%[%]a%^%]a%_%]a%`%]a%a%]a%j%]a%k%]a%l%]a%n%]a%o%]a%p%]a%q%]a%r%]a%s%]a%t%]a%z%]a&|%]at%]a#e%]a#p%]a'q%]a!d%]a~O%b5ZO%c%zO%d%{O%e%|O%f%}O%g%]a%h%]a%i%]a~P,4mO%g5]O%h&QO%i&RO%b%]a%c%]a%d%]a%e%]a%f%]a~P,4mOv$mOw$nO!O$lO!Q)VX![)VX!c)VX!g)VX!o)VX!x)VX#T)VX#V)VX#X)VX#p)VX#w)VX$`)VX$a)VX$b)VX$c)VX$d)VX%X)VX%Z)VX%[)VX%^)VX%_)VX%`)VX%a)VX%b)VX%c)VX%d)VX%e)VX%f)VX%g)VX%h)VX%i)VX%j)VX%k)VX%l)VX%n)VX%o)VX%p)VX%q)VX%r)VX%s)VX%t)VX%z)VX&|)VX'q)VX!d)VXr)VXt)VX#e)VX~Ov$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#V&WO#X5`O%X5WO%Z5XO%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%g5]O%h&QO%i&RO%j5cO%k&UO%l&VO%n5fO%o5gO%p5hO%q5iO%z&iO&|6nO~Or%ua%r%ua%s%ua%t%uat%ua#e%ua#p%ua'q%ua!d%ua~P,;iO!c'kO!g'kO#p(wX'q(wX!d(wX~P%2SOv$mOw$nO!O$lOQ*eXR*eXS*eXT*eXU*eXj*eXk*eXl*eXo(OXp*eXx*eXz*eX}*eX!P*eX!Q(OX!Q*eX!R*eX!T*eX!X*eX!Y*eX![(OX![*eX!^*eX!_*eX!`*eX!a*eX!c(OX!d(OX!d*eX!e*eX!g(OX!i*eX!l*eX!o(OX!o*eX!t*eX!v*eX!x(OX!z*eX!|*eX#O*eX#P*eX#R*eX#T(OX#T*eX#V(OX#V*eX#X(OX#X*eX#[*eX#]*eX#^*eX#_*eX#a*eX%X(OX%Z(OX%[(OX%^(OX%_(OX%`(OX%a(OX%b(OX%c(OX%d(OX%e(OX%f(OX%g(OX%h(OX%i(OX%j(OX%k(OX%l(OX%n(OX%o(OX%p(OX%q(OX%r(OX%s(OX%t(OX%v*eX%w*eX%x*eX%z(OX%z*eX%|*eX%}*eX&O*eX&P*eX&Q*eX&R*eX&U*eX&V*eX&W*eX&X*eX&Y*eX&`*eX&b*eX&c*eX&d*eX&i*eX&j*eX&l*eX&x*eX&z*eX&|(OX'O*eX'P*eX'Q*eX'S*eX'T*eX'V*eX'W*eX'X*eX'x*eX(S*eX(a*eX*j*eX~Or(OXr*eX!x*eX%X*eX%Z*eX%[*eX%^*eX%_*eX%`*eX%a*eX%b*eX%c*eX%d*eX%e*eX%f*eX%g*eX%h*eX%i*eX%j*eX%k*eX%l*eX%n*eX%o*eX%p*eX%q*eX%r*eX%s*eX%t*eX&|*eXt(OXt*eX#e(OX#e*eX#p(OX#p*eX'q(OX'q*eX~P,>yOr(^P!x(^P%X(^P%Z(^P%[(^P%^(^P%_(^P%`(^P%a(^P%b(^P%c(^P%d(^P%e(^P%f(^P%g(^P%h(^P%i(^P%j(^P%k(^P%l(^P%n(^P%o(^P%p(^P%q(^P%r(^P%s(^P%t(^P&|(^Pt(^P#e(^P#p(^P'q(^P~P)>sO!Q5aO![5bO!o5aO!x5`O#T5`O#X5`O%^5_O%_5_O%`5aO%a5bO%b5ZO%g5]O%j5cO~P&<tO!c5TO~P&@`Ov$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#V&WO#X5`O%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%g5]O%h&QO%i&RO%j5cO%k&UO%l&VO%n5fO%o5gO%p5hO%q5iO%z&iO&|6nO~Or&ya%X&ya%Z&ya%r&ya%s&ya%t&yat&ya#e&ya#p&ya'q&ya!d&ya~P,LhOo%TOt.kO!c%SOj&oXp&oXv#mXw&rX!g#YX!x#YX%X#YX%Z#YX%[#YX%^#YX%_#YX%`#YX%a#YX%b#YX%c#YX%d#YX%e#YX%f#YX%g#YX%h#YX%i#YX%j#YX%k#YX%l#YX%n#YX%o#YX%p#YX%q#YX%r#YX%s#YX%t#YX&|#YX~P!NROr!bi%r!bi%s!bi%t!bit!bi#e!bi#p!bi'q!bi!d!bi~P,;iOr%Wi%r%Wi%s%Wi%t%Wit%Wi#e%Wi#p%Wi'q%Wi!d%Wi~P,;iOr%Yi%r%Yi%s%Yi%t%Yit%Yi#e%Yi#p%Yi'q%Yi!d%Yi~P,;iOv$mOw$nO!O$lO%^5_O%z&iOr%]i!Q%]i![%]i!o%]i!x%]i#T%]i#V%]i#X%]i%X%]i%Z%]i%[%]i%`%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!d%]i~O%_5_O~P-%wO!Q5aO![5bO!o5aO!x5`O#T5`O#X5`O%^5_O%_5_O%`5aO%a5bO~P'3UO!Q5aO![5bO!o5aO!x5`O#T5`O#X5`O%^5_O%_5_O%`5aO%a5bO%b5ZO~P'6kO%_%]i~P-%wOv$mOw$nO!O$lO!x5`O#T5`O#X5`O%[%wO%^5_O%_5_O%z&iOr%]i![%]i#V%]i%X%]i%Z%]i%a%]i%b%]i%c%]i%d%]i%e%]i%f%]i%g%]i%h%]i%i%]i%j%]i%k%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!d%]i~O!Q%]i!o%]i%`%]i~P-*fO!Q5aO!o5aO%`5aO~P-*fOv$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#X5`O%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%z&iOr%]i#V%]i%X%]i%Z%]i%l%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!d%]i~O%g%]i%h%]i%i%]i%j%]i%k%]i~P--pO%g5]O%h&QO%i&RO%j5cO%k&UO~P--pOv$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#X5`O%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%g5]O%h&QO%i&RO%j5cO%k&UO%l&VO%z&iOr%]i%X%]i%Z%]i%n%]i%o%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!d%]i~O#V%]i~P-1QO#V&WO~P-1QOv$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#V&WO#X5`O%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%g5]O%h&QO%i&RO%j5cO%k&UO%l&VO%n5fO%z&iOr%]i%X%]i%Z%]i%p%]i%q%]i%r%]i%s%]i%t%]i&|%]it%]i#e%]i#p%]i'q%]i!d%]i~O%o%]i~P-4UO%o5gO~P-4UOv$mOw$nO!O$lO!Q5aO![5bO!o5aO!x5`O#T5`O#V&WO#X5`O%[%wO%^5_O%_5_O%`5aO%a5bO%b5ZO%c%zO%d%{O%e%|O%f%}O%g5]O%h&QO%i&RO%j5cO%k&UO%l&VO%n5fO%o5gO%p5hO%z&iOr%]i%r%]i%s%]i%t%]it%]i#e%]i#p%]i'q%]i!d%]i~O%X%]i%Z%]i%q%]i&|%]i~P-7YO%X5WO%Z5XO%q5iO&|6nO~P-7YO%r&XOr%]i%s%]i%t%]it%]i#e%]i#p%]i'q%]i!d%]i~P,;iO!d2OO~O!c*]a!d*]a!g*]a~P%2SO!d3_O~O!d3`O~Or%Yq%r%Yq%s%Yq%t%Yqt%Yq#e%Yq#p%Yq'q%Yq!d%Yq~P,;iOr&{q%X&{q%Z&{q%r&{q%s&{q%t&{qt&{q#e&{q#p&{q'q&{q!d&{q~P,LhO!c#gi!g#gi~P+8kOr#giv#giw#gi!O#gi!Q#gi![#gi!c!fi!g!fi!o#gi!x#gi#T#gi#V#gi#X#gi%X#gi%Z#gi%[#gi%^#gi%_#gi%`#gi%a#gi%b#gi%c#gi%d#gi%e#gi%f#gi%g#gi%h#gi%i#gi%j#gi%k#gi%l#gi%n#gi%o#gi%p#gi%q#gi%r#gi%s#gi%t#gi%z#gi&|#git#gi#e#gi#p#gi'q#gi!d#gi~Or&{y%X&{y%Z&{y%r&{y%s&{y%t&{yt&{y#e&{y#p&{y'q&{y!d&{y~P,LhO!c5TO~P?lOQ]OR6kOS6wOT4}OU$OOjQOkROlROp5UOxXOzSO}VO!OmO!P$eO!Q5SO!R$eO!T$fO!X$eO!Y6gO![^O!^`O!_aO!`bO!acO!e%ZO!iiO!llO!o6hO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5SO%w5SO%x#XO%z6jO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~Ow%rO~P-AcOQ]OR6kOS6wOT4}OU$OOjQOkROlROp5UOw%]OxXOzSO}VO!OmO!P$eO!Q5SO!R$eO!T$fO!X$eO!Y6gO![^O!^`O!_aO!`bO!acO!iiO!llO!o6hO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v5SO%w5SO%x#XO%z6jO%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~O!ehOr&SXv&SX!x&SX%X&SX%Z&SX%[&SX%^&SX%_&SX%`&SX%a&SX%b&SX%c&SX%d&SX%e&SX%f&SX%g&SX%h&SX%i&SX%j&SX%k&SX%l&SX%n&SX%o&SX%p&SX%q&SX%r&SX%s&SX%t&SX&|&SXt&SX#e&SX#p&SX'q&SX!d&SX~P-FsOQ]OR#dOS#kOT#}OU$OOkROlROwnOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$POr(^Pv(^Pw(^P!O(^P!Q(^P!o(^P!x(^P#T(^P#V(^P#X(^P%X(^P%Z(^P%[(^P%^(^P%_(^P%`(^P%a(^P%b(^P%c(^P%d(^P%e(^P%f(^P%g(^P%h(^P%i(^P%j(^P%k(^P%l(^P%n(^P%o(^P%p(^P%q(^P%r(^P%s(^P%t(^P%z(^P&|(^Pt(^P#e(^P#p(^P'q(^P!d(^P~Oj5pOp({O!e6qO&e(}O&f)OO&g)PO~P-N_Oj5qOp%XO!e6rO~P-N_O#e6ZO~P#JWO#e6bO~P&MOO!e6{O~P%'sO!d6eO~O!d6dO~OQ]OR#dOS#kOT#}OU$OOjQOkROlROp%XOxXOzSO}VO!OmO!P$eO!Q#YO!R$eO!T$fO!X$eO!YgO![^O!^`O!_aO!`bO!acO!e6{O!iiO!llO!ooO!trO!vtO!zwO!|yO#O{O#P|O#R!OO#T!PO#V!QO#X!RO#[!SO#]!TO#^!UO#_!VO#a!YO%v#YO%w#YO%x#XO%z#[O%|#]O%}#^O&O#_O&P#`O&Q#aO&R#bO&U#eO&V#fO&W#gO&X#hO&Y#iO&`#pO&b#rO&c#sO&d#tO&i#vO&j#wO&l#yO&x$RO&z$TO'O$VO'P$WO'Q$XO'S$[O'T$]O'V$`O'W$aO'X$bO'xvO(SUO(aqO*j$PO~OwnO~P.)jOk6zO!e)fO#R!OO~O#tx#n!R!P%wp!Yjkl!X#c!l%Z%`%z!l!Q!o%^!T#R#T#V#X!x!O%^~",
  goto: "&1`*{PPPPPPPPPPPPPPPPPPPPPPPP*|*|PPP+y,oPP-eP-hP-hPPP.^P.^.^PPPPP1tP6X9f<sPP<vP@WPPPP@WPPPC`PFjPIz@WPJQM_P@W@W@W@WP@WP@WP@WP@WP@WPP!!oP!'SP@WP@WP!*b@WPPPPJQP!-mP!-zP!.e!/]!1tP!2V!5_P!5hP!9WP!5_PPP!:c!5_P!5_P!5_P!5_P!5_!5_P!5_P!5_PPP!5_!5_P!;X!5_!;_PPPPPP!5_!;lP!;rP!5_!5_!<O!<XP!5_!5_!5_P!5_!5_!<z!5_PPPPP!5_!5_!5_!5_PP!=TPPP@WP@WPP@WPPPPPPPPPPPPPPP!=YPPPPPPP@WPPP@WP@WPPPPPP@W@WPPPPP@W!>m@W!Aw@WP@WPPPPPP@WPP@WP!EP@W!EW@W@W!Hc@W@W@W!Kk@WP@WP@WP@WPPP@WPP@WPPPP!Nu#!_#!e#!x##O##Y##a##x#$O#$U#%V#%^#%z#&Q#&W#&f#&p#&|#'S#(u#*dPPPPPPPPPPPPP#*j#+`#/e#3X#6oP#7[#:r#Al#EP#Hm#Hm#Hm#Ku#N}$$Z$%r$'SP$*`$-h$0p$3x$7Q$7d$7d$:l$>S$>S$>S$>S$A`$Ac$Ai$Dz$D}$E[$Ee$Hj$Hs$H|$I`$Id$Iz$I}$JR$JX$J]$Jf$Ji$JiIt$Jl$Js$KP$Kp$Ky$LS$LV$Ld$Lv$M]$Mr$Mr$NX$N_$Ne$Nr$Nr$Nr$Nr$NrP% O% O% X% ^% ^% ^% c%#W%#W%#W%#W%$w%$w%&d%'}%)d%*]%*]%+S%.^%.^%.^%.^%.^%.^%1f%4p%4p%4p%4p%4p%7x%;S%;W%;a%;a%;a%>k%>o%>o%>o%>x%?Q%?Q%B[%B`P%El%Hv%LQ& [& [& [&$d&$h&'p&'p&*x&*{&.T&.T&.T&1]Q$kP!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3pT,x'n,y!g$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3p!g$tUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3pR1{.z!g$wUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3p'yYOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*V*Y*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.].u.v/[0Y0^0a0d1V1Y1_1h1w1x2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3pS&x!O4{Q&z!PQ&|!QQ'Q!RS)n$f5RT)y$m$|'g]Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,X,c-f-u-y-z.P.R.S.U.W.]/[/}0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|'g[Ohmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'S'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,X,c-f-u-y-z.P.R.S.U.W.]/[/}0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|R*d%P'm_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.]/[0Y0^0a0d1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|'akOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|'`kOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q,s'hR2u0dQ%ajR*t%b'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|V(u#q(w4|'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|U(u#q(w4|R,o'e'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3pQ)e$ZQ)h$_Q)k$dQ.^)fQ._)iQ.`)lR6z6}'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q)k$dR.`)l'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|R,n'eS'{!g%_Q-W'wQ0S,[R0k-Q!P't!g%_'u'w'{'},[-T-U-W-Y-]-_0Q0S0U0m0o0p2h2i2k3tS'|!g%_S-S'u'}Q-X'wU0T,[-U-YQ0i-OS0n-T-_U2g0Q0U0pQ2v0mS3u2h2kR4c3tt'r!g%_'u'w'},[-O-T-U-Y-_0Q0U0m0p2h2k3tQ(S!qQ(T!rQ(U!sQ(Z!uQ(]!vW(q#k#l6w6xS(s#n6yS)y$m$|Q*e%RQ+P%tQ,b'YQ,e'ZQ-d(VQ-e(WS-g(X(^Q.X)[Q.i)yQ0X,cQ1Q-hS1g.]6tQ2n0YQ2x0rQ3T1RQ3]1fQ3^1hQ3a1nS3w2o2pQ4R3UR4f3xS'}!g%_Q-T'uQ-Y'wS0U,[-UR2h0Q^!wOn$h%W%p'y*kS'z!g%_Q(Y!tQ(h#PU(r#l#|6xW)Q#u(|6l6qS)X#x6mS)a$Q5OS)b$S5PQ,^'WQ-V'wQ-Z'xS-^'{'|Q-a(SQ-b(TQ-c(UQ-m(ZQ-p(]Q-r(bS.W)V6rU0R,[-W-XQ0V,_S0l-S-]Q0{-dQ0|-eQ1P-gU2j0S0T0oQ2w0nQ2{0vQ3S1QS3s2g2iQ3{2vQ3|2xQ4Q3TQ4T3WQ4d3uQ4h4OQ4j4RQ4q4cQ4y4uR4z4x_#WOn$h%W%p'y*k'[#mOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q'P!QQ'W![S'Y!_!`Q'j!cQ)[#zQ0Y,fR1f.Z#c'o!e!w!y%i%m%u'W'Y'b'c'j'w(Y([(d*i*z*{,[,_,b,c,g,i,k,o,s-W-X-f-l-n-o/W0S0T0X0Y0o0}1O2g2i2n2o2p2q2u3V3u3w3x3}4c4fW(q#k#l6w6xS(s#n6yQ+P%tQ,b'YQ0X,cS1g.]6tQ2n0YQ3^1hS3w2o2pR4f3xQ'w!gR,['US!pO$hU%in%p'yT*i%W*kX0s-a-b0t0xQ0w-aQ0y-bQ2z0tR2|0x_!tOn$h%W%p'y*kQ(d!wQ-l(YQ0z-cQ1U-mQ1X-pQ2}0{Q3O0|Q3R1PQ4P3SQ4i4QR4t4j_!yOn$h%W%p'y*kV%nn%p'y![&bp%Y%e%g(O(k(o)d*f+R+S+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^!c5e)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5m5t5v5w5x6T6U6V6W6X6Y6a6c6f6s%S#nOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X6y$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6n']#oOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|S)y$m$|R1n.j'[#zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|R.Z)]']#|Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|%S$QOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X5O$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6nQ$vUQ&lqQ)s$jr*]$v&l)s*_+l+p+s+v+|.|/`/e/m/s/u2^3pQ*_$zQ+l&mQ+p&oQ+s&qQ+v&rQ+|&tQ.|*`Q/`+mQ/e+qQ/m+wQ/s+{Q/u+}Q2^/pR3p2aQ*U$sR.s*Ub$pTWjsuxz}+yS)}$p.lT.l*O.nQ.n*OR1p.nQ*Q$qS.o*Q.qR.q*SS%OZ,VR*b%O[*n%Y%e-n0}1b1cQ-v(oQ-}5VW/R*n-v-}/YR/Y5nQ*r%`R/S*rQ0O,YR2f0OS'u!g%_f-R'u-U-]-_0Q0m0o0p2i2k3tQ-U'wQ-]'{Q-_'}Q0Q,[Q0m-TQ0o-WQ0p-YQ2i0SQ2k0UR3t2hS%pn'yR*|%pd%Uf%X'i({)c){.g5U5s5uW*h%U,T,],`S,T'O)ZQ,]'VR,`'XQ,y'nR0e,yQ0b,rR2t0bQ'm!dU,w'm-`1ZQ-`(PR1Z-wQ0t-aQ0x-bT2y0t0x^!xOn$h%W%p'y*kR(f!xQ*k%WR/O*k!f&Pp%Y%e%g(O(k(o)^)d*f+R+S+X+^+_+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^S+W&P5[!m5[)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5m5r5t5v5w5x5|6Q6R6S6T6U6V6W6X6Y6a6c6f6s!b&Tp%Y%e%g(O(k(o)^)d*f+R+S+_+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^S+Y&T5^!i5^)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5m5r5t5v5w5x6R6S6T6U6V6W6X6Y6a6c6f6sQ$hOR)p$h!g$yUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3p'`ZOhmno!X!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%^%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|!f$xUq$j$v$z&l&m&o&q&r&t)s*_*`+l+m+p+q+s+v+w+{+|+}.|/`/e/m/p/s/u2^2a3pV,V'S,X/}'l_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.]/[0Y0^0a0d1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q.t*VQ.x*YQ1t.uQ1u.vQ3d1xR3e1w'yTOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*V*Y*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.].u.v/[0Y0^0a0d1V1Y1_1h1w1x2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q$rTQ${WQ%bjQ&nsQ&puQ&sxQ&uzQ&w}R/o+y'yWOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'^'b'e'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*V*Y*k*m+U+h,c,f,q-f-u-y-z.P.R.S.U.W.].u.v/[0Y0^0a0d1V1Y1_1h1w1x2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|[pO$h%W%p'y*kQ%Yhr%em%Z%]%r'q(R(|)V-y.P.U.W6o6q6r6{6|Q%gnW%so#Y5S6hS(O!j'lQ(k#ZS(l#[6j`(o#k#l#n.]6t6w6x6yQ)^#}Q)d$UQ)u$lQ)|$nQ*f%SQ*u%dQ+R%vQ+S%xS+T%y&]Q+V&OQ+X&SQ+Z&[Q+[&^Q+]&_Q+^&`Q+_&aQ+`&bQ+a&cQ+b&dQ+c&eQ+d&fQ+e&gQ+f&hQ+g&jQ,Q&yQ,R&{Q,S&}Q,U'RQ,d'ZQ-n([Q-|(yQ.a)oQ.f)vQ.h)wS/Q*m-uQ/Z+UQ/]+hQ0}-fS1]-z6]Q1b.RQ1c.SQ2P/[Q2q0^Q3V1VQ3Y1_Q3}3PQ4k4SQ4s4g`5V#u#x)T)U)X5q6l6m`5l#d$Q$S(r1Y5O5P6kQ5m6i`5n%t'Y,c0Y1h2o2p3xQ5r4}Q5t5QQ5v5TQ5w5WQ5x5XS5y5Y5`Q5{5ZQ5|5]Q5}5_Q6O5aQ6P5bQ6Q5cQ6R5dQ6S5eQ6T5fQ6U5gQ6V5hQ6W5iQ6X5jQ6Y5kQ6^6pQ6a5zQ6c6ZQ6f6bR6s6n'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|S'T!X%^S,W'S/}R/|,X'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q,g'^Q,k'bQ,n'eU,p'h0a0dQ0Y,fR0`,q']dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|'[$eOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|T,h'`'bS%[h%ZS%fm.RU%hn%].SS)R#u6lS)W#x6mQ+O%rW,}'q(R([-fQ.O(|Q.Q)TU.T)U)X5qQ.V)VQ1[-yQ1a.PS1d.U.WQ6[6oQ6_6qQ6`6rQ6u6{R6v6|W'l!d'm(P-`b*m%Y%e*n-n/Y0}1b1c5nQ,f'[W-u(o-v-}5VQ.])eS/},Y0OQ0^,nS0a,r0bS1Y-w1ZQ1_-{Q1h.^Q2o0YQ3x2pQ6].eR6t6z'ejOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'`'b'h'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^0d1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']sOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']zOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q+{&tU/p+z+|+}Q/v,OS2a/t/uR2c/w']}Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|^!XOn$h%W%p'y*k&|%^hmo!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q(R([(r(y(|)T)U)V)X)o)v)w*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|Q(_!vQ-i(XQ-q(`R1S-j'e!WOhmno!j!v#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R(X([(`(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-j-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|R,Z'SQ,Y'SR2e/}^!gOn$h%W%p'y*k'S%_hmo!j#Y#Z#[#d#k#l#n#q#u#x#}$Q$S$U$l$n%S%Z%]%d%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q(R([(r(w(y(|)T)U)V)X)o)v)w*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4|4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|T'U!X!hR-Q'sS$gO$hU%on%p'yT*j%W*k_![On$h%W%p'y*kQ'p!eQ(c!wQ(g!yQ*x%iQ*y%mQ+Q%uQ,^'WQ,a'YQ,j'bQ,l'cQ,u'jQ-V'wS-k(Y(dQ-o([Q.}*iS/V*z*{U0R,[-W-XQ0V,_S0W,b,cQ0Z,gQ0[,iQ0],kQ0_,oQ0c,sQ1O-fQ1T-lQ1V-nQ1W-oQ1}/WU2j0S0T0oQ2l0XQ2m0YQ3P0}Q3Q1OS3s2g2iU3v2n2o2pQ3y2qQ3z2uQ4S3VQ4d3uS4e3w3xQ4g3}Q4q4cR4r4f_!_On$h%W%p'y*k_!`On$h%W%p'y*kq(p#k#l#n%t'Y,c.]0Y1h2o2p3x6t6w6x6yT'[!_!`^!qOn$h%W%p'y*k^%tp!p%g%i%m*i*{T'Z!_!`R'^!_T'`!_!`Q,i'`R,k'bT'b!_!`_!cOn$h%W%p'y*kR'e!_R'h!_S,r'h0dR2s0a^!eOn$h%W%p'y*kR-x(r^!dOn$h%W%p'y*kQ(P!jS(n#d6kS)a$Q5OS)b$S5PS,v'l1YR-w(r_!hOn$h%W%p'y*k_!jOn$h%W%p'y*kR(Q!jY%up!p%g%i*iQ*z%mR/W*{^!rOn$h%W%p'y*k_%tp!p%g%i%m*i*{^!sOn$h%W%p'y*k^%tp!p%g%i%m*i*{R(V!t^!uOn$h%W%p'y*k^%tp!p%g%i%m*i*{R(W!t^!vOn$h%W%p'y*k^%tp!p%g%i%m*i*{R(X!tX0r-a-b0t0xX0v-a-b0t0xg(b!w(Y-c-m-p0{0|1P3S4Q4j^#POn$h%W%p'y*kR'x!g_#VOn$h%W%p'y*kV%on%p'yV%mn%p'y!l%yp%Y%e%g(O(k(o)^)d*f+R+S+V+X+[+]+^+_+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^!s5Y)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5m5r5t5v5w5x5{5|6O6P6Q6R6S6T6U6V6W6X6Y6a6c6f6s!h&Op%Y%e%g&P(O(k(o)^)d*f+R+S+X+^+_+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^!o5Z)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5[5m5r5t5v5w5x5|6Q6R6S6T6U6V6W6X6Y6a6c6f6s!d&Sp%Y%e%g&T(O(k(o)^)d*f+R+S+_+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^!k5])u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5^5m5r5t5v5w5x6R6S6T6U6V6W6X6Y6a6c6f6s!b&`p%Y%e%g(O(k(o)^)d*f+R+S+_+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^!i5c)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5m5r5t5v5w5x6R6S6T6U6V6W6X6Y6a6c6f6s!^&ap%Y%e%g(O(k(o)d*f+R+S+`+a+b+c+d+e+f,d-n/Q/Z/]0}1b1c2P5V5n6^!e5d)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s5m5t5v5w5x6S6T6U6V6W6X6Y6a6c6f6sp&gp%Y%e%g(O(o+f,d-n/Q0}1b1c5V5n6^w5j)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s6Y6sn&hp%Y%e%g(O(o,d-n/Q0}1b1c5V5n6^u5k)u)|*u+g,Q,R,S,U.a.f.h2q3V3Y3}4k4s6s%S#ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X6i$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6n']#cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|%S#lOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X6x$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6n']#jOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|%S#qOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X4|$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6nT(x#q4|Q(v#qQ-{(wR.e4|%S#uOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X6l$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6nT)S#u6lW)Q#u(|6l6qR)`$OS)T#u6lT.P(|6q%S#xOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X6m$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6nT)Y#x6m'[#{Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|T)z$m$|%S$SOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X5P$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6n%S$UOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X5Q$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6n%S$ZOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h%S%W%Z%]%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h'Y'Z'l'q'y(R([(r(y(|)T)U)V)X*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y1Y1h2o2p3x5q6l6m6o6p6q6r6t6w6x6y6{6|#X6}$l$n%d&j&y&{&}'R)o)v)w0^1V1_3P4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5z6Z6]6b6h6i6j6k6n']$YOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|T)g$Z6}']$_Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']$^Ohmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|R)j$_']$dOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|']$cOhmno!j#Y#Z#[#d#k#l#n#u#x#}$Q$S$U$h$l$n%S%W%Z%]%d%p%r%t%v%x%y&O&S&[&]&^&_&`&a&b&c&d&e&f&g&h&j&y&{&}'R'Y'Z'l'q'y(R([(r(y(|)T)U)V)X)o)v)w*k*m+U+h,c-f-u-y-z.P.R.S.U.W.]/[0Y0^1V1Y1_1h2o2p3P3x4S4g4}5O5P5Q5S5T5W5X5Y5Z5]5_5`5a5b5c5d5e5f5g5h5i5j5k5q5z6Z6]6b6h6i6j6k6l6m6n6o6p6q6r6t6w6x6y6{6|R)m$d",
  nodeNames: "⚠ UnrestrictedIdentifier SpecialScalarVariable NamedUnaryOperator ListOperator FileTestOp IOOperatorStart Glob ReadonlySTDIN IOOperatorEnd HeredocStartIdentifier HeredocEndIdentifier InterpolatedStringContent EscapeSequence QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter QuoteLikeEndDelimiter StringContent QWElement RegexOptions PodDirective PodContent PodCut Comment UninterpolatedHeredocBody InterpolatedHeredocBody ScalarVariable ArrayVariable HashVariable PackageVariable PackageName :: Identifier PackageVariableName ] ArrayAccessVariable } HashAccessVariable ArrowOperator { StringSingleQuoted StringQQuoted q StringDoubleQuoted StringQqQuoted qq [ Integer ArithOp Float ScalarDereference $ PackageVariable PackageName PackageVariableName TypeGlob Option HeredocInitializer << SpecialLiteral __FILE__ __LINE__ __PACKAGE__ __SUB__ Pair FatComma ) ( List Comma QWList qw QWListContent ArrayLength $# ArrayRef HashRef ArithOp ArrayAccessVariable HashAccessVariable BacktickQuoted CommandQxQuoted qx PatternMatchM m PatternMatch / RegexQr qr SubstitutionS s TransliterationTrOrY tr y ArrayDereference @ HashDereference % FunctionDereference & TypeGlobDereference * Constant VariableDeclaration our state my local AnonymousFunction sub FunctionPrototype Prototype FunctionAttribute : FunctionSignature ParenthesizedArguments FunctionPrototypeAttribute prototype Block PackageStatement package PackageName Version StatementEnd ; UseNoStatement use no ModuleName Arguments UseNoIfStatement if UseLibStatement lib UseNoSubsStatement subs UseNoFeatureStatement feature UseNoVersion RequireStatement require UseConstantStatement constant UseParentOrBaseStatement parent base NoRequire ExpressionStatement FunctionDefinition async FunctionName SingleLineStatement ReturnExpression return unless while until for foreach IfStatement ElsifClause elsif ElseClause else UnlessStatement WhileStatement Label Continue continue UntilStatement ForStatement1 ForStatement2 \\ StandaloneBlock NamedBlockStatement NamedBlock SpecialBlock BEGIN UNITCHECK CHECK INIT END Ellipsis EmptyStatement PodStatement EndDataStatement __END__ __DATA__ LoopControlStatement next last redo Assignment = UpdateExpression UpdateOp x BinaryExpression ArithOp BindingOp ConcatOp BitOp CompareOp lt gt le ge CompareOp eq ne CompareOp cmp isa BitOp BitOp LogicOp LogicOp RangeOp and or xor UnaryExpression LogicOp RefOp not UpdateExpression ArithOp NoArgumentNamedUnaryOperator fork getpid time times wait wantarray NamedUnaryExpression ListOperatorExpression grep map join sort unpack CallExpression FunctionName CallExpressionWithBareword FunctionName Bless bless OutputFunction print say printf STDIN STDERR STDOUT SystemCall exec system MethodInvocation SUPER FunctionName IndirectMethodInvocation FunctionName CallExpressionRecursive ArrayFunction FunctionName FileTest IOOperator EvalExpression Eval DoExpression do GotoExpression goto TernaryExpression LogicOp ArrayModifierFunction push unshift splice ArrayPopOrShift pop shift HashOrArrayDestructureFunction each values keys Program",
  maxTerm: 456,
  context: contextTracker,
  nodeProps: [
    ["group", -64,2,26,27,28,40,41,43,44,47,49,50,52,55,56,57,59,64,68,70,73,75,76,78,79,80,81,83,85,87,89,91,94,96,98,100,102,103,108,192,194,197,221,225,227,234,235,241,243,245,247,254,257,260,262,263,265,266,267,269,271,273,275,279,282,"Expression",-26,119,125,130,132,134,136,138,139,141,143,147,148,151,159,164,165,169,170,171,173,174,176,182,183,184,185,"Statement"],
    ["closedBy", 6,"IOOperatorEnd",39,"}",46,"]",67,")"],
    ["openedBy", 9,"IOOperatorStart",34,"[",36,"{",66,"("],
    ["isolate", -2,23,40,""]
  ],
  skippedNodes: [0],
  repeatNodeCount: 21,
  tokenData: "!.V~RzXY#uYZ#u]^#upq#uqr#zrs$ast'qtu(Yuv,[vw/xwx1uxy<^yz<cz{<h{|AV|}Bv}!OB{!O!PHj!P!QKd!Q!RKw!R![M_![!]! }!]!^!![!^!_!#R!_!`!#s!`!a!$W!a!b!$p!b!c!$u!c!}!(f!}#O!(w#O#P!)n#P#Q!*g#Q#R!+^#R#S!+i#S#T!,P#T#j!(f#j#k!,U#k#o!(f#o#p!-]#p#q!-b#q#r!-p#r#s!-u~#zO'|~~$PQ%v~!_!`$V#r#s$[~$[O%g~~$aO%_~~$fU(S~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~${UOY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~%bWOY$xZ!O$x!O!P%_!P#d$x#d#e%z#e;'S$x;'S;=`'k<%lO$x~%}WOY$xZ!O$x!O!P%_!P#a$x#a#b&g#b;'S$x;'S;=`'k<%lO$x~&jWOY$xZr$xrs'Ss!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'XU#t~OY$xZ!O$x!O!P%_!P;'S$x;'S;=`'k<%lO$x~'nP;=`<%l$x~'vSg~OY'qZ;'S'q;'S;=`(S<%lO'q~(VP;=`<%l'q~(a_#c`!T~st)`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!c!}*Y!}#O)e#O#P)e#P#Q)e#R#S*Y#T#o*Y#o#p*k~)eO!l~`)jY#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~*_Sj~!Q![*Y!c!}*Y#R#S*Y#T#o*Y~*nVXY*kYZ*k]^*kpq*k!c!}+T#R#S+T#T#o+T~+WXXY+sYZ+s]^+spq+s!Q![+T!c!}+T#R#S+T#T#o+T#q#r,V~+vTXY+sYZ+s]^+spq+s#q#r,V~,[Oj~~,ca#c`#T~qr-htu)euv)evw)ez{)e{|-m}!O-h!Q![.d!]!^)e!_!`.u!b!c)e!c!}.d!}#O)e#O#P.z#P#Q)e#R#S.d#T#o.d~-mOl~~-tYl~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~.iSl~!Q![.d!c!}.d#R#S.d#T#o.d~.zO%Z~~/PZ#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R/r~/uP!c!}-h~0P[#c`#V~tu)euv)evw0uz{)e{|)e!O!P1o!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~0|Z%oQ#c`tu)euv)evw)ez{)e{|)e!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~1rP!_!`.u~1zZx~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P;'S1u;'S;=`<W<%lO1u~2rVx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X<%lO2m~3^Ox~~3aRO;'S2m;'S;=`3j;=`O2m~3oWx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X;=`<%l2m<%lO2m~4[P;=`<%l2m~4dUx~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~4yUOY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~5`WOY4vZ!O4v!O!P5]!P#d4v#d#e5x#e;'S4v;'S;=`7i<%lO4v~5{WOY4vZ!O4v!O!P5]!P#a4v#a#b6e#b;'S4v;'S;=`7i<%lO4v~6hWOY4vZw4vwx7Qx!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~7VU#t~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~7lP;=`<%l4v~7t]x~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P#d1u#d#e9w#e;'S1u;'S;=`<W<%lO1u~8pWOY1uYZ2mZ!O1u!O!P7o!P;'S1u;'S;=`9Y;=`<%l2m<%lO1u~9_Wx~Ow2mwx3Xx#O2m#O#P3^#P;'S2m;'S;=`4X;=`<%l1u<%lO2m~9|]x~OY1uYZ2mZw1uwx4_x!O1u!O!P7o!P#O1u#O#P8m#P#a1u#a#b:u#b;'S1u;'S;=`<W<%lO1u~:zZx~OY1uYZ2mZw1uwx;mx!O1u!O!P7o!P#O1u#O#P8m#P;'S1u;'S;=`<W<%lO1u~;tU#t~x~OY4vZ!O4v!O!P5]!P;'S4v;'S;=`7i<%lO4v~<ZP;=`<%l1u~<cO!e~~<hO!d~~<o_#c`#X~tu)euv)evw)ez{=n{|)e!]!^)e!_!`.u!b!c)e!c!}>h!}#O)e#O#P)e#P#Q)e#R#S>h#T#o>h#o#p?c~=uZ#c`%^~tu)euv)evw)ez{)e{|)e!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~>mT!X~!Q![>h![!]>|!c!}>h#R#S>h#T#o>h~?PP![!]?S~?VS!c!}>h#R#S>h#T#o>h#o#p?c~?fVXY?cYZ?c]^?cpq?c!c!}?{#R#S?{#T#o?{~@OXXY@kYZ@k]^@kpq@k!Q![?{!c!}?{#R#S?{#T#o?{#q#r@}~@nTXY@kYZ@k]^@kpq@k#q#r@}~ASP!X~![!]>|~A^Z#c`!o~tu)euv)evw)ez{)e{|BP!]!^)e!_!`.u!b!c)e!}#O)e#O#P)e#P#Q)e~BWY#c`%z~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~B{O!g~~CQW!Qk}!OCj!_!`.u!`!aCo!c!}Ct#R#SCt#T#bCt#b#cDV#c#oCt~CoO%z~~CtOv~kCyS!Yk!Q![Ct!c!}Ct#R#SCt#T#oCtoD[U!Yk!Q![Ct!c!}Ct#R#SCt#T#cCt#c#dDn#d#oCtoDsU!Yk!Q![Ct!c!}Ct#R#SCt#T#fCt#f#gEV#g#oCtoE[U!Yk!Q![Ct!c!}Ct#R#SCt#T#XCt#X#YEn#Y#oCtoEsU!Yk!Q![Ct!c!}Ct#R#SCt#T#eCt#e#fFV#f#oCtoF[U!Yk!Q![Ct!c!}Ct#R#SCt#T#iCt#i#jFn#j#oCtoFsU!Yk!Q![Ct!c!}Ct#R#SCt#T#]Ct#]#^GV#^#oCtoG[U!Yk!Q![Ct!c!}Ct#R#SCt#T#fCt#f#gGn#g#oCtoGsU!Yk!Q![Ct!c!}Ct#R#SCt#T#XCt#X#YHV#Y#oCtoH^S$WS!Yk!Q![Ct!c!}Ct#R#SCt#T#oCt~HqS#n[%`Q!O!PH}!Q![JP!_!`.u#R#SIq_IUR%qQ#n[!O!PI_!Q![Iq#R#SIq_IhR)iP%qQ#n[!O!PIq!Q![Iq#R#SIq[IvR#n[!O!PIq!Q![Iq#R#SIq~JWT#n[!R~!O!PIq!Q![JP!g!hJg#R#SKU#X#YJg~JjR{|Js}!OJs!Q![Jy~JvP!Q![Jy~KOQ!R~!Q![Jy#R#SJs~KZR#n[!O!PIq!Q![JP#R#SIq~KiQ!x~!P!QKo!_!`.u~KtP%p~!_!`.u~LO[#n[!P~!O!PJP!Q!YLt!Y![M_!d!eNf!g!hJg!q!rN}!z!{! `#R#SMu#U#VNf#X#YJg#c#dN}#l#m! `~L{U#n[!P~!O!PJP!Q!YLt!Y![M_!g!hJg#R#SNT#X#YJg~MfT#n[!P~!O!PJP!Q![M_!g!hJg#R#SMu#X#YJg~MzR#n[!O!PIq!Q![M_#R#SIq~NYS#n[!O!PIq!Q!YLt!Y![M_#R#SIq~NiQ!Q!RNo!R!SNo~NtR!P~!Q!RNo!R!SNo#R#SNf~! QP!Q!Y! T~! YQ!P~!Q!Y! T#R#SN}~! cR!Q![! l!c!i! l#T#Z! l~! qS!P~!Q![! l!c!i! l#R#S! `#T#Z! l~!!SP#e~![!]!!V~!![Oo~o!!cY#p_#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!#WQ%b~!^!_!#^!_!`!#f~!#cP![~!_!`.u~!#kP%b~!`!a!#n~!#sO%j~~!#xR%X~!_!`$V!`!a!$R#r#s$[~!$WO!c~~!$]Q%b~!_!`!$c!`!a!$h~!$hO%b~~!$mP%a~!_!`.u~!$uO&|~~!$|c#c`#R~qr!&Xtu)euv)evw)ez{)e{|!&^|!Q!&X!Q![!'T![!]!&X!]!^!&^!^!b!&X!b!c!&^!c!}!'T!}#O!&^#O#P!'f#P#Q!&^#Q#R!&X#R#S!'T#T#o!'T~!&^Ok~~!&eYk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!'YSk~!Q![!'T!c!}!'T#R#S!'T#T#o!'T~!'mZk~#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e#Q#R!(`~!(cP!c!}!&X~!(kSp~!Q![!(f!c!}!(f#R#S!(f#T#o!(f~!)OY#c`!O~tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)eo!)wY$rS%wk#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)ec!*nYrR#c`tu)euv)evw)ez{)e{|)e!]!^)e!b!c)e!}#O)e#O#P)e#P#Q)e~!+cQ%n~!O!P1o!_!`.u~!+pT#n[p~!O!PIq!Q![!+i!c!}!(f#R#S!+i#T#o!(f~!,UO(a~~!,ZTp~!O!P!,j!Q![!,u!c!}!(f#R#S!(f#T#o!(f[!,oQ#n[!O!P!,j!Q![!,j~!,|T#n[p~!O!P!,j!Q![!,u!c!}!(f#R#S!(f#T#o!(f~!-bOw~~!-gR%n~!O!P1o!_!`.u#p#qKo~!-uOt~~!-zQ%v~!O!P!.Q#r#s!#n~!.VO%v~",
  tokenizers: [semicolon, unrestrictedIdentifier, specialScalarVariable, builtinOperator, fileIO, heredoc, interpolated, quoteLikeOperator, regex, pod, endData, 0, 1, 2, 3, 4],
  topRules: {"Program":[0,286]},
  dynamicPrecedences: {"152":1,"185":4,"268":1,"322":1,"324":1,"327":1,"331":1,"332":1,"333":1,"334":1,"338":1,"340":1,"341":1,"342":1,"343":1,"345":1,"346":1,"348":1,"349":1,"350":1,"351":1,"354":1,"355":1,"357":1,"359":1,"360":1,"363":1,"364":1,"365":1,"367":1,"368":1,"369":1,"370":1,"371":1,"376":1,"377":1,"380":1,"381":1,"382":1,"383":1,"384":1,"385":1,"386":1,"387":1,"388":1,"389":1,"390":1,"391":1,"392":1,"394":1,"395":1,"397":1,"398":1,"399":1,"400":1,"401":1,"402":1,"403":1,"404":1,"405":1,"406":1,"407":1,"408":1,"409":1,"410":1,"411":1,"412":1,"413":1,"414":1,"415":1,"416":1,"417":1,"418":1,"420":1,"421":1,"422":1,"423":1,"424":1,"425":1,"428":1,"429":1,"430":1,"432":1,"433":1,"434":1,"436":1,"437":1,"439":1,"441":1,"442":1,"443":1,"444":1,"445":1,"446":1,"448":1,"449":1,"450":1,"452":1,"453":1,"454":1,"455":1},
  specialized: [{term: 32, get: (value) => spec_Identifier[value] || -1}],
  tokenPrec: 28159
});

const perlLanguage = LRLanguage.define({
    name: 'perl',
    parser: parser.configure({
        props: [
            indentNodeProp.add({
                IfStatement: continuedIndent({ except: /^\s*({|else\b|elsif\b)/ }),
                Block: delimitedIndent({ closing: '}' }),
                'StringSingleQuoted StringQQuoted StringDoubleQuoted StringQqQuoted QWList': () => null,
                'StatementEnd InterpolatedHeredocBody UninterpolatedHeredocBody': () => null,
                Statement: continuedIndent()
            }),
            foldNodeProp.add({
                'Block Array ArrayRef HashRef': foldInside,
                'InterpolatedHeredocBody UninterpolatedHeredocBody': (node) => {
                    if (node.prevSibling && node.lastChild)
                        return { from: node.prevSibling.to, to: node.lastChild.from };
                    return null;
                },
                PodStatement(node) {
                    if (node.firstChild?.type.name === 'PodDirective' &&
                        node.firstChild.nextSibling?.type.name === 'PodContent')
                        return { from: node.firstChild.nextSibling.from, to: node.firstChild.nextSibling.to };
                    return null;
                },
                EndDataStatement: (node) => (node.firstChild ? { from: node.firstChild.to, to: node.to } : null)
            }),
            styleTags({
                'do continue else elsif for foreach goto if last next redo return unless until when while': tags.controlKeyword,
                'bless local my our state sub': tags.definitionKeyword,
                'package use no import require parent base': tags.moduleKeyword,
                'constant feature lib subs async prototype': tags.modifier,
                'NamedUnaryOperator ListOperator Eval each exec fork getpid grep': tags.function(tags.keyword),
                'join keys map pop print printf push say shift sort splice system time times': tags.function(tags.keyword),
                'unpack unshift values wait wantarray': tags.function(tags.keyword),
                'BEGIN CHECK END INIT UNITCHECK': tags.processingInstruction,
                '__FILE__ __LINE__ __PACKAGE__ __SUB__': tags.literal,
                'ScalarVariable SpecialScalarVariable ArrayVariable HashVariable': tags.variableName,
                'ArrayLength/Identifier Prototype Constant/Identifier': tags.variableName,
                'PackageVariable/PackageVariableName/...': tags.variableName,
                'PackageName/Identifier PackageName/UnrestrictedIdentifier PackageName/ScalarVariable': tags.namespace,
                'PackageName/ArrayVariable PackageName/HashVariable SUPER': tags.namespace,
                'NamedType/...': tags.typeName,
                Name: tags.name,
                'Label/Identifier LabelName/Identifier STDIN STDERR STDOUT IOOperator/Identifier': tags.labelName,
                'MemberExpression/Identifier': tags.propertyName,
                'MemberExpression/ScalarVariable': tags.special(tags.propertyName),
                'FunctionName/PackageName/... FunctionName/Identifier': tags.function(tags.definition(tags.variableName)),
                UpdateOp: tags.updateOperator,
                'ArithOp "*" % "/"': tags.arithmeticOperator,
                'LogicOp and not or xor : FileTestOp': tags.logicOperator,
                BitOp: tags.bitwiseOperator,
                '<<': tags.special(tags.bitwiseOperator),
                'CompareOp < lt gt le ge eq ne cmp isa': tags.compareOperator,
                '=': tags.definitionOperator,
                '$ $# @ % & "*" ArrowOperator \\': tags.derefOperator,
                'ScalarDereference/{ ScalarDereference/}': tags.derefOperator,
                'ArrayDereference/{ ArrayDereference/}': tags.derefOperator,
                'HashDereference/{ HashDereference/}': tags.derefOperator,
                'FunctionDereference/{ FunctionDereference/}': tags.derefOperator,
                'TypeGlobDereference/{ TypeGlobDereference/}': tags.derefOperator,
                'ConcatOp BindingOp RangeOp RefOp x': tags.operator,
                Comment: tags.lineComment,
                Integer: tags.integer,
                Float: tags.float,
                'StringSingleQuoted StringDoubleQuoted q qq qx */StringContent */InterpolatedStringContent': tags.string,
                '*/QuoteLikeStartDelimiter QuoteLikeSeparatorDelimiter */QuoteLikeEndDelimiter': tags.string,
                'qw QWListContent/... Pair/Identifier HashAccessVariable/Identifier Version': tags.string,
                'HeredocInitializer/... HeredocEndIdentifier Glob': tags.string,
                'm qr s tr y RegexOptions': tags.special(tags.string),
                'PodStatement EndDataStatement/...': tags.blockComment,
                EscapeSequence: tags.escape,
                'Comma FatComma': tags.punctuation,
                '( )': tags.paren,
                '[ ]': tags.squareBracket,
                '{ }': tags.brace,
                '; :: :': tags.separator
            })
        ]
    }),
    languageData: { commentTokens: { line: '#' } }
});
const perlCompletion = perlLanguage.data.of({
    autocomplete: completeFromList([
        { label: 'my', type: 'keyword' },
        { label: 'use', type: 'keyword' },
        { label: 'sub', type: 'keyword' }
    ])
});
const perl = () => new LanguageSupport(perlLanguage, [perlCompletion]);

export { perl, perlCompletion, perlLanguage };
